@@ -27,7 +27,7 @@
       Arith      atan2           Arc tangent of two fields
 */
 
-#include "cdi.h"
+#include <cdi.h>
 #include "cdo.h"
 #include "cdo_int.h"
 #include "pstream.h"
@@ -35,7 +35,7 @@
 
 void *Arith(void *argument)
 {
-  static char func[] = "Arith";
+  static const char *func = "Arith";
   int operatorID;
   int operfunc;
   enum {FILL_NONE, FILL_TS, FILL_REC, FILL_RECTS, FILL_FILE};
@@ -64,7 +64,7 @@ void *Arith(void *argument)
   cdoOperatorAdd("atan2", func_atan2, 0, NULL);
 
   operatorID = cdoOperatorID();
-  operfunc = cdoOperatorFunc(operatorID);
+  operfunc = cdoOperatorF1(operatorID);
 
   streamID1 = streamOpenRead(cdoStreamName(0));
   if ( streamID1 < 0 ) cdiError(streamID1, "Open failed on %s", cdoStreamName(0));
@@ -123,7 +123,7 @@ void *Arith(void *argument)
     }
 
   if ( filltype == FILL_NONE )
-    vlistCompare(vlistID1, vlistID2, func_sft);
+    vlistCompare(vlistID1, vlistID2, CMP_SFT);
 
   gridsize = vlistGridsizeMax(vlistIDx1);
 
@@ -214,7 +214,7 @@ void *Arith(void *argument)
 		  vlistID2 = streamInqVlist(streamID2);
 		  vlistIDx2 = vlistID2;
 
-		  vlistCompare(vlistID1, vlistID2, func_sft);
+		  vlistCompare(vlistID1, vlistID2, CMP_SFT);
 
 		  nrecs2 = streamInqTimestep(streamIDx2, tsID2);
 		  if ( nrecs2 == 0 )
