@@ -25,7 +25,7 @@
 */
 
 
-#include "cdi.h"
+#include <cdi.h>
 #include "cdo.h"
 #include "cdo_int.h"
 #include "pstream.h"
@@ -33,7 +33,7 @@
 
 void *Arithc(void *argument)
 {
-  static char func[] = "Arithc";
+  static const char *func = "Arithc";
   int operatorID;
   int operfunc;
   int streamID1, streamID2;
@@ -54,7 +54,7 @@ void *Arithc(void *argument)
   cdoOperatorAdd("divc", func_div, 0, NULL);
 
   operatorID = cdoOperatorID();
-  operfunc = cdoOperatorFunc(operatorID);
+  operfunc = cdoOperatorF1(operatorID);
 
   operatorInputArg("constant value");
   rconst = atof(operatorArgv()[0]);
