@@ -23,16 +23,11 @@
 */
 
 
-#include "cdi.h"
+#include <cdi.h>
 #include "cdo.h"
 #include "cdo_int.h"
 #include "pstream.h"
 
-#include <math.h>
-
-#ifndef  M_PI
-#define  M_PI		3.14159265358979323846	/* pi */
-#endif
 
 #ifndef  DEG2RAD
 #define  DEG2RAD  (M_PI/180.)   /* conversion for deg to rad */
@@ -40,7 +35,7 @@
 
 void *Arithlat(void *argument)
 {
-  static char func[] = "Arithlat";
+  static const char *func = "Arithlat";
   int operatorID;
   int operfunc;
   int streamID1, streamID2;
@@ -62,7 +57,7 @@ void *Arithlat(void *argument)
   cdoOperatorAdd("divcoslat", func_div, 0, NULL);
 
   operatorID = cdoOperatorID();
-  operfunc = cdoOperatorFunc(operatorID);
+  operfunc = cdoOperatorF1(operatorID);
 
   streamID1 = streamOpenRead(cdoStreamName(0));
   if ( streamID1 < 0 ) cdiError(streamID1, "Open failed on %s", cdoStreamName(0));
