@@ -20,7 +20,7 @@
 */
 
 
-#include "cdi.h"
+#include <cdi.h>
 #include "cdo.h"
 #include "cdo_int.h"
 #include "pstream.h"
@@ -28,7 +28,7 @@
 
 void *CDItest(void *argument)
 {
-  static char func[] = "CDItest";
+  static const char *func = "CDItest";
   int NCOPY;
   int operatorID;
   int streamID1, streamID2;
