@@ -25,7 +25,7 @@
 #  include "config.h" /* large file */
 #endif
 
-#include "cdi.h"
+#include <cdi.h>
 #include "cdo.h"
 #include "cdo_int.h"
 #include "pstream.h"
@@ -34,7 +34,7 @@ void    vlistDefVarTime(int vlistID, int varID, int timeID);
 
 void *Cat(void *argument)
 {
-  static char func[] = "Cat";
+  static const char *func = "Cat";
   int streamID1, streamID2 = CDI_UNDEFID;
   int nrecs;
   int tsID1, tsID2 = 0, recID, varID, levelID;
@@ -85,7 +85,7 @@ void *Cat(void *argument)
 	      vlistID2 = streamInqVlist(streamID2);
 	      taxisID2 = vlistInqTaxis(vlistID2);
 
-	      vlistCompare(vlistID1, vlistID2, func_sft);
+	      vlistCompare(vlistID1, vlistID2, CMP_SFT);
 
 	      tsID2 = vlistNtsteps(vlistID2);
 	      if ( tsID2 == 0 ) tsID2 = 1; /* bug fix for constant data only */
