@@ -21,7 +21,7 @@
       Change_e5slm      change_e5slm          Change ECHAM5 sea land mask
 */
 
-#include "cdi.h"
+#include <cdi.h>
 #include "cdo.h"
 #include "cdo_int.h"
 #include "pstream.h"
@@ -47,7 +47,7 @@ void minmax(int nvals, double *array, double *minval, double *maxval)
 
 void *Change_e5slm(void *argument)
 {
-  static char func[] = "Change_e5slm";
+  static const char *func = "Change_e5slm";
   int streamIDslm, streamID1, streamID2;
   const char *fn_slm;
   char name[256];
