@@ -26,7 +26,7 @@
       Comp       gt              Greater than
 */
 
-#include "cdi.h"
+#include <cdi.h>
 #include "cdo.h"
 #include "cdo_int.h"
 #include "pstream.h"
@@ -34,7 +34,7 @@
 
 void *Comp(void *argument)
 {
-  static char func[] = "Comp";
+  static const char *func = "Comp";
   int EQ, NE, LE, LT, GE, GT;
   int operatorID;
   enum {FILL_NONE, FILL_TS, FILL_REC};
@@ -102,7 +102,7 @@ void *Comp(void *argument)
     }
 
   if ( filltype == FILL_NONE )
-    vlistCompare(vlistID1, vlistID2, func_sft);
+    vlistCompare(vlistID1, vlistID2, CMP_SFT);
 
   nospec(vlistID1);
   nospec(vlistID2);
