@@ -22,7 +22,7 @@
       Cond       ifnotthen       If not then
 */
 
-#include "cdi.h"
+#include <cdi.h>
 #include "cdo.h"
 #include "cdo_int.h"
 #include "pstream.h"
@@ -30,7 +30,7 @@
 
 void *Cond(void *argument)
 {
-  static char func[] = "Cond";
+  static const char *func = "Cond";
   int IFTHEN, IFNOTTHEN;
   int operatorID;
   enum {FILL_NONE, FILL_TS, FILL_REC};
@@ -78,7 +78,7 @@ void *Cond(void *argument)
     }
 
   if ( filltype == FILL_NONE )
-    vlistCompare(vlistID1, vlistID2, func_sft);
+    vlistCompare(vlistID1, vlistID2, CMP_SFT);
   
   nospec(vlistID1);
   nospec(vlistID2);
