@@ -23,7 +23,7 @@
 */
 
 
-#include "cdi.h"
+#include <cdi.h>
 #include "cdo.h"
 #include "cdo_int.h"
 #include "pstream.h"
@@ -31,7 +31,7 @@
 
 void *Condc(void *argument)
 {
-  static char func[] = "Condc";
+  static const char *func = "Condc";
   int IFTHENC, IFNOTTHENC;
   int operatorID;
   int streamID1, streamID2;
