@@ -34,7 +34,7 @@
 #  include <omp.h>
 #endif
 
-#include "cdi.h"
+#include <cdi.h>
 #include "cdo.h"
 #include "cdo_int.h"
 #include "field.h"
@@ -45,7 +45,7 @@ enum {CONSECSUM, CONSECTS};
 
 static void selEndOfPeriod(field_t *periods, field_t history, field_t current, int isLastTimestep)
 {
-  static char func[] = "selEndOfPeriod";
+  static const char *func = "selEndOfPeriod";
   long   i, len;
   double pmissval = periods->missval;
   double  *parray = periods->ptr;
@@ -127,13 +127,13 @@ static void selEndOfPeriod(field_t *periods, field_t history, field_t current, i
 
 void *Consecstat (void *argument)
 {
-  static char func[] = "Consecstat";
+  static const char *func = "Consecstat";
   int operatorID;
 
   int i;
   int istreamID, itaxisID, ivlistID, itsID;
   int ostreamID, otaxisID, ovlistID, otsID;
-  int vdate, vtime;
+  int vdate = 0, vtime = 0;
   int histvdate = 0, histvtime = 0;
   int recID, nrecs;
   int varID, nvars;
