@@ -21,7 +21,7 @@
       Copy       copy            Copy datasets
 */
 
-#include "cdi.h"
+#include <cdi.h>
 #include "cdo.h"
 #include "cdo_int.h"
 #include "par_io.h"
@@ -31,7 +31,7 @@ void    vlistDefVarTime(int vlistID, int varID, int timeID);
 
 void *Copy(void *argument)
 {
-  static char func[] = "Copy";
+  static const char *func = "Copy";
   int COPY, SELALL;
   int operatorID;
   int streamID1, streamID2 = CDI_UNDEFID;
@@ -101,8 +101,8 @@ void *Copy(void *argument)
 	}
       else
 	{
-	  vlistCompare(vlistID1, vlistID2, func_sft);
-	  /* vlistCompare(vlistID1, vlistID2, func_hrd); */
+	  vlistCompare(vlistID1, vlistID2, CMP_SFT);
+	  /* vlistCompare(vlistID1, vlistID2, CMP_HRD); */
 	}
 
       tsID1 = 0;
