@@ -30,17 +30,19 @@
 
 #define WEIGHTS 1
 
-#include "cdi.h"
+#include <cdi.h>
 #include "cdo.h"
 #include "cdo_int.h"
 #include "pstream.h"
 #include "statistic.h"
 
+
+
 // NO MISSING VALUE SUPPORT ADDED SO FAR
 
 void *EOFs(void * argument)
 {
-  static char func[] = "EOFs";
+  static const char *func = "EOFs";
   enum {EOF_, EOF_TIME, EOF_SPATIAL};
   int operatorID;
   int operfunc;
@@ -86,13 +88,14 @@ void *EOFs(void * argument)
     timer_start(timer_init);
   }
 
+
   cdoInitialize(argument);
   cdoOperatorAdd("eof",       EOF_,       0, NULL);
   cdoOperatorAdd("eoftime",   EOF_TIME,   0, NULL);
   cdoOperatorAdd("eofspatial",EOF_SPATIAL,0, NULL);
 
   operatorID  = cdoOperatorID();
-  operfunc    = cdoOperatorFunc(operatorID);
+  operfunc    = cdoOperatorF1(operatorID);
 
   operatorInputArg("Number of eigen functions to write out");
   n_eig       = atoi(operatorArgv()[0]);
@@ -312,7 +315,6 @@ void *EOFs(void * argument)
           int i2;
           double tmp;
 
-
           streamInqRecord(streamID1, &varID, &levelID);
           gridsize = gridInqSize(vlistInqVarGrid(vlistID1, varID));
 
@@ -447,26 +449,34 @@ void *EOFs(void * argument)
 
           /* SOLVE THE EIGEN PROBLEM */
 	  if ( cdoTimer ) timer_start(timer_eig);
-          eigen_solution_of_symmetric_matrix(&cov[0], &eigv[0], n, n, func);
+	  
+	  parallel_eigen_solution_of_symmetric_matrix(&cov[0],&eigv[0],n,n,func);
+
 	  if ( cdoTimer ) timer_stop(timer_eig);
-          /* NOW: cov contains the eigenvectors, eigv the eigenvalues */
+	  /* NOW: cov contains the eigenvectors, eigv the eigenvalues */
 	  // need to multiply igen values by sum_w
 	  // TODO --> find out why!
-
+	  
 	  if ( cdoTimer ) timer_start(timer_post);
           for (i = 0; i < n; i++)
             eigenvalues[varID][levelID][i].ptr[0] = eigv[i]*sum_w;
-
+	  
           for (i = 0; i < n_eig; i++)
             {
               if ( grid_space )
 		// Do not need to normalize by
 		// w[pack[j]]/sum_w (checked) --> find out why!!!
+		//#if defined (_OPENMP)
+		//#pragma omp parallel for private(j)
+		//#endif
 		for(j = 0; j < npack; j++)
 		  eigenvectors[varID][levelID][i].ptr[pack[j]] = 
 		    cov[i][j] / sqrt(weight[pack[j]]);
               else if ( time_space )
                 {
+#if defined (_OPENMP)
+#pragma omp parallel for private(i2,j,sum) shared(datafields,eigenvectors)
+#endif
                   for ( i2 = 0; i2 < npack; i2++ )
                     {
                       sum = 0;
@@ -477,6 +487,11 @@ void *EOFs(void * argument)
                     }
                   // NORMALIZING
                   sum = 0;
+
+#if defined (_OPENMP)
+#pragma omp parallel for private(i2) default(none) reduction(+:sum)	\
+  shared(eigenvectors,weight,pack,varID,levelID,i,npack)
+#endif
                   for ( i2 = 0; i2 < npack; i2++ )
                     sum += weight[pack[i2]] *
                            eigenvectors[varID][levelID][i].ptr[pack[i2]] *
@@ -485,11 +500,19 @@ void *EOFs(void * argument)
                     {
                       sum = sqrt(sum);
 		      // sum = sqrt(sum/sum_w);
+#if defined (_OPENMP)
+#pragma omp parallel for private(i2) default(none) \
+  shared(npack,varID,levelID,i,pack,sum,eigenvectors)
+#endif
                       for( i2 = 0; i2 < npack; i2++ )
                         eigenvectors[varID][levelID][i].ptr[pack[i2]] /= sum;
                     }
                   else
 		    {
+#if defined (_OPENMP)
+#pragma omp parallel for private(i2) default(none) \
+  shared(npack,varID,levelID,i,pack,sum,eigenvectors,missval)
+#endif
 		      for( i2 = 0; i2 < npack; i2++ )
 			eigenvectors[varID][levelID][i].ptr[pack[i2]] = missval;
 		    }
@@ -581,3 +604,4 @@ void *EOFs(void * argument)
 
   return (0);
 }
+
