@@ -21,7 +21,7 @@
       Enlarge    enlarge         Enlarge fields
 */
 
-#include "cdi.h"
+#include <cdi.h>
 #include "cdo.h"
 #include "cdo_int.h"
 #include "pstream.h"
@@ -30,7 +30,7 @@
 
 void *Enlarge(void *argument)
 {
-  static char func[] = "Enlarge";
+  static const char *func = "Enlarge";
   int streamID1, streamID2;
   int vlistID1, vlistID2;
   int gridID1, gridID2;
