@@ -32,7 +32,7 @@
 #  include <omp.h>
 #endif
 
-#include "cdi.h"
+#include <cdi.h>
 #include "cdo.h"
 #include "cdo_int.h"
 #include "pstream.h"
@@ -41,12 +41,12 @@
 
 void *Ensstat(void *argument)
 {
-  static char func[] = "Ensstat";
+  static const char *func = "Ensstat";
   int operatorID;
   int operfunc;
   int i;
   int nvars;
-  int cmpfunc;
+  int cmpflag;
   int varID, recID;
   int gridsize = 0;
   int gridID;
@@ -88,7 +88,7 @@ void *Ensstat(void *argument)
   /* QR */
 
   operatorID = cdoOperatorID();
-  operfunc = cdoOperatorFunc(operatorID);
+  operfunc = cdoOperatorF1(operatorID);
 
   /* RQ */
   if ( operfunc == func_pctl )
@@ -139,12 +139,12 @@ void *Ensstat(void *argument)
   /* check that the contents is always the same */
   nvars = vlistNvars(ef[0].vlistID);
   if ( nvars == 1 ) 
-    cmpfunc = func_sftn;
+    cmpflag = CMP_NAME | CMP_GRIDSIZE | CMP_NLEVEL | CMP_GRID;
   else
-    cmpfunc = func_sftn;
+    cmpflag = CMP_NAME | CMP_GRIDSIZE | CMP_NLEVEL | CMP_GRID;
 
   for ( fileID = 1; fileID < nfiles; fileID++ )
-    vlistCompare(ef[0].vlistID, ef[fileID].vlistID, cmpfunc);
+    vlistCompare(ef[0].vlistID, ef[fileID].vlistID, cmpflag);
 
   vlistID1 = ef[0].vlistID;
   vlistID2 = vlistDuplicate(vlistID1);
