@@ -23,7 +23,7 @@
       Filedes    vct             Vertical coordinate table
 */
 
-#include "cdi.h"
+#include <cdi.h>
 #include "cdo.h"
 #include "cdo_int.h"
 #include "pstream.h"
