@@ -24,7 +24,7 @@
 */
 
 
-#include "cdi.h"
+#include <cdi.h>
 #include "cdo.h"
 #include "cdo_int.h"
 #include "pstream.h"
@@ -141,7 +141,7 @@ void filter(const int nts, const int *fmasc, double *array1, double *array2)
 
 void *Filter(void *argument)
 {
-  static char func[] = "Filter";
+  static const char *func = "Filter";
   enum {BAND, HIGH, LOW};
   char *tunits[] = {"second", "minute", "hour", "day", "month", "year"};
   int iunits[] = {31536000, 525600, 8760, 365, 12, 1};
@@ -176,7 +176,7 @@ void *Filter(void *argument)
   cdoOperatorAdd("lowpass" ,  LOW,   0, NULL);
 
   operatorID = cdoOperatorID();
-  operfunc = cdoOperatorFunc(operatorID);
+  operfunc = cdoOperatorF1(operatorID);
   
   streamID1 = streamOpenRead(cdoStreamName(0));
   if ( streamID1 < 0 ) cdiError(streamID1, "Open failed on %s", cdoStreamName(0));
