@@ -22,7 +22,7 @@
 */
 
 
-#include "cdi.h"
+#include <cdi.h>
 #include "cdo.h"
 #include "cdo_int.h"
 #include "pstream.h"
@@ -58,7 +58,7 @@ double corr(double * restrict in0, double * restrict in1,
 
   out = wsum0 ?
         FDIV((sum01 * wsum0 - sum0 * sum1),
-	     FROOT((sum00 * wsum0 - sum0 * sum0) *
+	     FSQRT((sum00 * wsum0 - sum0 * sum0) *
 		   (sum11 * wsum0 - sum1 * sum1))) : missval;
 
   return (out);
@@ -67,7 +67,7 @@ double corr(double * restrict in0, double * restrict in1,
 
 void *Fldstat2(void *argument)
 {
-  static char func[] = "Fldstat2";
+  static const char *func = "Fldstat2";
   int operatorID;
   int operfunc;
   int streamID1, streamID2, streamID3;
@@ -93,7 +93,7 @@ void *Fldstat2(void *argument)
   cdoOperatorAdd("fldcor", 0, 0, NULL);
 
   operatorID = cdoOperatorID();
-  operfunc = cdoOperatorFunc(operatorID);
+  operfunc = cdoOperatorF1(operatorID);
 
   if ( operfunc == func_mean || operfunc == func_avg ||
        operfunc == func_var  || operfunc == func_std )
@@ -109,7 +109,7 @@ void *Fldstat2(void *argument)
   vlistID2 = streamInqVlist(streamID2);
   vlistID3 = vlistDuplicate(vlistID1);
 
-  vlistCompare(vlistID1, vlistID2, func_sft);
+  vlistCompare(vlistID1, vlistID2, CMP_SFT);
 
   taxisID1 = vlistInqTaxis(vlistID1);
   taxisID2 = vlistInqTaxis(vlistID2);
