@@ -31,7 +31,7 @@
 #  include <omp.h>
 #endif
 
-#include "cdi.h"
+#include <cdi.h>
 #include "cdo.h"
 #include "cdo_int.h"
 #include "pstream.h"
@@ -41,7 +41,7 @@
 static
 int genBoxGrid(int gridID1, int xinc, int yinc)
 {
-  static char func[] = "genBoxGrid";
+  static const char *func = "genBoxGrid";
   int i, j, i1;
   int gridID2 = -1, gridtype;
   int gridsize1 = 0, nlon1 = 0, nlat1 = 0;
@@ -503,7 +503,7 @@ int genBoxGrid(int gridID1, int xinc, int yinc)
 static
 void gridboxstat(field_t *field1, field_t *field2, int xinc, int yinc, int statfunc)
 {
-  static char func[] = "gridboxstat";
+  static const char *func = "gridboxstat";
   int nlon1, nlat1;
   int nlon2, nlat2;
   int ilat, ilon;
@@ -599,7 +599,7 @@ void gridboxstat(field_t *field1, field_t *field2, int xinc, int yinc, int statf
 
 void *Gridboxstat(void *argument)
 {
-  static char func[] = "Gridboxstat";
+  static const char *func = "Gridboxstat";
   int operatorID;
   int operfunc;
   int streamID1, streamID2;
@@ -633,7 +633,7 @@ void *Gridboxstat(void *argument)
   cdoOperatorAdd("gridboxstd",  func_std,  0, NULL);
 
   operatorID = cdoOperatorID();
-  operfunc = cdoOperatorFunc(operatorID);
+  operfunc = cdoOperatorF1(operatorID);
 
   if ( operfunc == func_mean || operfunc == func_avg ||
        operfunc == func_var  || operfunc == func_std )
