@@ -21,7 +21,7 @@
       Harmonic   harmonic        Harmonic
 */
 
-#include "cdi.h"
+#include <cdi.h>
 #include "cdo.h"
 #include "cdo_int.h"
 #include "pstream.h"
@@ -29,7 +29,7 @@
 
 void *Harmonic(void *argument)
 {
-  static char func[] = "Harmonic";
+  static const char *func = "Harmonic";
   int gridsize;
   int nrecs;
   int varID, levelID, recID;
