@@ -20,7 +20,7 @@
 
 */
 
-#include "cdi.h"
+#include <cdi.h>
 #include "cdo.h"
 #include "cdo_int.h"
 #include "pstream.h"
@@ -29,7 +29,7 @@
 
 void *Histogram(void *argument)
 {
-  static char func[] = "Histogram";
+  static const char *func = "Histogram";
   int HISTCOUNT, HISTSUM, HISTMEAN, HISTFREQ;
   int operatorID;
   int streamID1, streamID2;
