@@ -1,6 +1,6 @@
 #include <ctype.h>
 
-#include "cdi.h"
+#include <cdi.h>
 #include "cdo.h"
 #include "cdo_int.h"
 #include "pstream.h"
@@ -92,7 +92,7 @@ int getDate(const char *name)
 
 void *Importobs(void *argument)
 {
-  static char func[] = "Importobs";
+  static const char *func = "Importobs";
   int operatorID;
   char line[MAX_LINE_LEN];
   int streamID;
