@@ -23,7 +23,7 @@
 */
 
 
-#include "cdi.h"
+#include <cdi.h>
 #include "cdo.h"
 #include "cdo_int.h"
 #include "pstream.h"
@@ -219,7 +219,7 @@ void printMap(int nlon, int nlat, double *array, double missval, double min, dou
 
 void *Info(void *argument)
 {
-  static char func[] = "Info";
+  static const char *func = "Info";
   int INFO, INFOV, INFOP, MAP;
   int operatorID;
   int i;
