@@ -25,7 +25,7 @@
 
 
 #include <stdio.h>
-#include "cdi.h"
+#include <cdi.h>
 #include "cdo.h"
 #include "cdo_int.h"
 #include "pstream.h"
@@ -68,7 +68,7 @@ static int input_darray(int nval, double *array)
 
 void *Input(void *argument)
 {
-  static char func[] = "Input";
+  static const char *func = "Input";
   int INPUT, INPUTSRV, INPUTEXT;
   int operatorID;
   int varID = 0;
