@@ -22,7 +22,7 @@
 
 #include <ctype.h>
 
-#include "cdi.h"
+#include <cdi.h>
 #include "cdo.h"
 #include "cdo_int.h"
 #include "pstream.h"
@@ -54,7 +54,7 @@ int readnextpos(FILE *fp, int calendar, juldate_t *juldate, double *xpos, double
 
 void *Intgridtraj(void *argument)
 {
-  static char func[] = "Intgridtraj";
+  static const char *func = "Intgridtraj";
   int streamID1, streamID2;
   int nrecs, nvars, nlevel;
   int index, ngrids;
