@@ -22,7 +22,7 @@
 */
 
 
-#include "cdi.h"
+#include <cdi.h>
 #include "cdo.h"
 #include "cdo_int.h"
 #include "pstream.h"
@@ -31,7 +31,7 @@
 
 void *Intntime(void *argument)
 {
-  static char func[] = "Intntime";
+  static const char *func = "Intntime";
   int streamID1, streamID2;
   int nrecs, nvars, nlevel;
   int i, nrecords;
