@@ -23,7 +23,7 @@
 
 #include <ctype.h>  /* isdigit */
 
-#include "cdi.h"
+#include <cdi.h>
 #include "cdo.h"
 #include "cdo_int.h"
 #include "pstream.h"
@@ -32,7 +32,7 @@
 
 void *Inttime(void *argument)
 {
-  static char func[] = "Inttime";
+  static const char *func = "Inttime";
   int streamID1, streamID2;
   int nrecs, nvars, nlevel;
   int i, nrecords;
