@@ -23,7 +23,7 @@
 
 #include <ctype.h>
 
-#include "cdi.h"
+#include <cdi.h>
 #include "cdo.h"
 #include "cdo_int.h"
 #include "pstream.h"
@@ -33,7 +33,7 @@
 
 void *Intyear(void *argument)
 {
-  static char func[] = "Intyear";
+  static const char *func = "Intyear";
   int streamID1, streamID2;
   int nrecs;
   int i, iy;
