@@ -24,7 +24,7 @@
 
 #include <math.h>
 
-#include "cdi.h"
+#include <cdi.h>
 #include "cdo.h"
 #include "cdo_int.h"
 #include "pstream.h"
@@ -32,7 +32,7 @@
 
 static void mastrfu(int gridID, int zaxisID, double *array1, double *array2)
 {
-  static char func[] = "mastrfu";
+  static const char *func = "mastrfu";
   int nlev;
   int nlat;
   int ilev, ilat, n;
@@ -86,7 +86,7 @@ static void mastrfu(int gridID, int zaxisID, double *array1, double *array2)
 
 void *Mastrfu(void *argument)
 {
-  static char func[] = "Mastrfu";
+  static const char *func = "Mastrfu";
   int streamID1, streamID2;
   int nrecs;
   int tsID, recID, varID, levelID;
