@@ -35,7 +35,7 @@
 */
 
 
-#include "cdi.h"
+#include <cdi.h>
 #include "cdo.h"
 #include "cdo_int.h"
 #include "pstream.h"
@@ -43,7 +43,7 @@
 
 void *Math(void *argument)
 {
-  static char func[] = "Math";
+  static const char *func = "Math";
   enum {ABS, FINT, FNINT, SQR, SQRT, EXP, LN, LOG10, SIN, COS, TAN, ASIN, ACOS, ATAN, POW, RECI};
   int operatorID;
   int operfunc;
@@ -80,7 +80,7 @@ void *Math(void *argument)
   cdoOperatorAdd("reci",  RECI,  0, NULL);
  
   operatorID = cdoOperatorID();
-  operfunc = cdoOperatorFunc(operatorID);
+  operfunc = cdoOperatorF1(operatorID);
 
   if ( operfunc == POW )
     {
@@ -144,7 +144,7 @@ void *Math(void *argument)
 	      break;
 	    case SQRT:
 	      for ( i = 0; i < gridsize; i++ )
-		array2[i] = DBL_IS_EQUAL(array1[i], missval1) ? missval1 : ROOT(array1[i]);
+		array2[i] = DBL_IS_EQUAL(array1[i], missval1) ? missval1 : SQRT(array1[i]);
 	      break;
 	    case EXP:
 	      for ( i = 0; i < gridsize; i++ )
