@@ -22,7 +22,7 @@
 */
 
 
-#include "cdi.h"
+#include <cdi.h>
 #include "cdo.h"
 #include "cdo_int.h"
 #include "pstream.h"
@@ -31,7 +31,7 @@
 
 void *Merge(void *argument)
 {
-  static char func[] = "Merge";
+  static const char *func = "Merge";
   int streamID1 = -1, streamID2 = -1;
   int varID, varID2;
   int nrecs = 0;
