@@ -21,7 +21,7 @@
 */
 
 
-#include "cdi.h"
+#include <cdi.h>
 #include "cdo.h"
 #include "cdo_int.h"
 #include "pstream.h"
@@ -29,7 +29,7 @@
 
 static void gen_index(int gridID1, int gridID2, int *index)
 {
-  static char func[] = "gen_index";
+  static const char *func = "gen_index";
   int nlat1, nlon1;
   int nlat2, nlon2;
   int gridtype1, gridtype2;
@@ -151,7 +151,7 @@ static void gen_index(int gridID1, int gridID2, int *index)
 
 void *Mergegrid(void *argument)
 {
-  static char func[] = "Mergegrid";
+  static const char *func = "Mergegrid";
   int varID;
   int nrecs = 0;
   int tsID, recID, levelID;
@@ -182,7 +182,7 @@ void *Mergegrid(void *argument)
 
   vlistID2 = streamInqVlist(streamID2);
 
-  vlistCompare(vlistID1, vlistID2, func_code);
+  vlistCompare(vlistID1, vlistID2, CMP_CODE | CMP_NLEVEL);
 
   ndiffgrids = 0;
   for ( index = 1; index < vlistNgrids(vlistID1); index++ )
