@@ -22,7 +22,7 @@
 */
 
 
-#include "cdi.h"
+#include <cdi.h>
 #include "cdo.h"
 #include "cdo_int.h"
 #include "pstream.h"
@@ -31,7 +31,7 @@
 
 void *Mergetime(void *argument)
 {
-  static char func[] = "Mergetime";
+  static const char *func = "Mergetime";
   int streamID1, streamID2 = CDI_UNDEFID;
   int tsID2 = 0, recID, varID, levelID;
   int vlistID1, vlistID2;
@@ -80,7 +80,7 @@ void *Mergetime(void *argument)
   
   /* check that the contents is always the same */
   for ( fileID = 1; fileID < nfiles; fileID++ )
-    vlistCompare(sf[0].vlistID, sf[fileID].vlistID, func_hrd);
+    vlistCompare(sf[0].vlistID, sf[fileID].vlistID, CMP_HRD);
 
   /* read the first time step */
   for ( fileID = 0; fileID < nfiles; fileID++ )
