@@ -21,7 +21,7 @@
       Mrotuv      mrotuv          Forward rotation for MPIOM data
 */
 
-#include "cdi.h"
+#include <cdi.h>
 #include "cdo.h"
 #include "cdo_int.h"
 #include "pstream.h"
@@ -193,7 +193,7 @@ void p_to_uv_grid(int nlon, int nlat, double *grid1x, double *grid1y,
 
 void *Mrotuv(void *argument)
 {
-  static char func[] = "Mrotuv";
+  static const char *func = "Mrotuv";
   int streamID1, streamID2, streamID3;
   int nrecs;
   int tsID, recID, levelID;
