@@ -21,7 +21,7 @@
       Mrotuvb     mrotuvb          Backward rotation for MPIOM data
 */
 
-#include "cdi.h"
+#include <cdi.h>
 #include "cdo.h"
 #include "cdo_int.h"
 #include "pstream.h"
@@ -155,7 +155,7 @@ static
 void uv_to_p_grid(int nlon, int nlat, double *grid1x, double *grid1y, 
 		  double *grid2x, double *grid2y, double *grid3x, double *grid3y)
 {
-  static char func[] = "uv_to_p_grid";
+  static const char *func = "uv_to_p_grid";
   int gridsizex;
   int i, j;
   double gx, gy;
@@ -261,7 +261,7 @@ void uv_to_p_grid(int nlon, int nlat, double *grid1x, double *grid1y,
 
 void *Mrotuvb(void *argument)
 {
-  static char func[] = "Mrotuvb";
+  static const char *func = "Mrotuvb";
   int streamID1, streamID2, streamID3;
   int nrecs, nrecs2;
   int tsID, recID, levelID;
