@@ -21,7 +21,7 @@
 */
 
 
-#include "cdi.h"
+#include <cdi.h>
 #include "cdo.h"
 #include "cdo_int.h"
 #include "pstream.h"
@@ -29,7 +29,7 @@
 
 void *Pinfo(void *argument)
 {
-  static char func[] = "Pinfo";
+  static const char *func = "Pinfo";
   int PINFO, PINFOV;
   int operatorID;
   int i;
