@@ -24,7 +24,7 @@
 
 #include <ctype.h>
 
-#include "cdi.h"
+#include <cdi.h>
 #include "cdo.h"
 #include "cdo_int.h"
 #include "pstream.h"
@@ -34,7 +34,7 @@
 
 void *Pressure(void *argument)
 {
-  static char func[] = "Pressure";
+  static const char *func = "Pressure";
   int PRESSURE_FL, PRESSURE_HL, DELTAP_FL, DELTAH_FL;
   int operatorID;
   int mode;
