@@ -22,7 +22,7 @@
 */
 
 
-#include "cdi.h"
+#include <cdi.h>
 #include "cdo.h"
 #include "cdo_int.h"
 #include "pstream.h"
@@ -31,7 +31,7 @@
 /* Same code as Trend ! */
 void *Regres(void *argument)
 {
-  static char func[] = "Regres";
+  static const char *func = "Regres";
   int gridsize;
   int vdate = 0, vtime = 0;
   int nrecs, nrecords;
