@@ -35,7 +35,7 @@
       Remap       remap           SCRIP grid remapping
 */
 
-#include "cdi.h"
+#include <cdi.h>
 #include "cdo.h"
 #include "cdo_int.h"
 #include "pstream.h"
@@ -46,6 +46,8 @@
 enum {REMAPCON, REMAPCON2, REMAPBIL, REMAPBIC, REMAPDIS, REMAPNN, REMAPLAF, REMAPSUM,
       GENCON, GENCON2, GENBIL, GENBIC, GENDIS, GENNN, GENLAF, REMAPXXX};
 
+enum {HEAP_SORT, MERGE_SORT};
+
 static
 void get_map_type(int operfunc, int *map_type, int *submap_type, int *remap_order)
 {
@@ -146,7 +148,7 @@ int maptype2operfunc(int map_type, int submap_type, int remap_order)
 
 void *Remap(void *argument)
 {
-  static char func[] = "Remap";
+  static const char *func = "Remap";
   int operatorID;
   int operfunc;
   int streamID1, streamID2 = -1;
@@ -189,6 +191,7 @@ void *Remap(void *argument)
   int remap_restrict_type = RESTRICT_LATITUDE;
   int remap_num_srch_bins = 180;
   int lremap_num_srch_bins = FALSE;
+  int sort_mode = HEAP_SORT;
 
   cdoInitialize(argument);
 
@@ -210,8 +213,8 @@ void *Remap(void *argument)
   cdoOperatorAdd("remap",       REMAPXXX,    0, NULL);
 
   operatorID = cdoOperatorID();
-  operfunc   = cdoOperatorFunc(operatorID);
-  lwrite_remap = cdoOperatorIntval(operatorID);
+  operfunc   = cdoOperatorF1(operatorID);
+  lwrite_remap = cdoOperatorF2(operatorID);
 
   if ( operfunc == REMAPDIS || operfunc == GENDIS ||
        operfunc == REMAPNN  || operfunc == GENNN )
@@ -273,6 +276,28 @@ void *Remap(void *argument)
 	}
     }
 
+#if defined (_OPENMP)
+  if ( ompNumThreads == 1 )
+    sort_mode = HEAP_SORT;
+  else
+    sort_mode = MERGE_SORT;
+#endif
+
+  envstr = getenv("REMAP_SORT_MODE");
+  if ( envstr )
+    {
+      if      ( strcmp(envstr, "heap")  == 0 ) sort_mode = HEAP_SORT;
+      else if ( strcmp(envstr, "merge") == 0 ) sort_mode = MERGE_SORT;
+
+      if ( cdoVerbose )
+	{
+	  if      ( sort_mode == HEAP_SORT )
+	    cdoPrint("Set sort_mode to HEAP_SORT");
+	  else if ( sort_mode == MERGE_SORT )
+	    cdoPrint("Set sort_mode to MERGE_SORT");
+	}
+    }
+
   envstr = getenv("REMAP_RESTRICT_TYPE");
   if ( envstr )
     {
@@ -509,7 +534,7 @@ void *Remap(void *argument)
 	  remaps[0].grid.grid2_vgpm = (int *) realloc(remaps[0].grid.grid2_vgpm,
 						      gridInqSize(gridID2)*sizeof(int));
 	  gridID2_gme = gridToCell(gridID2);
-	  gridInqMask(gridID2_gme, remaps[0].grid.grid2_vgpm);
+	  gridInqMaskGME(gridID2_gme, remaps[0].grid.grid2_vgpm);
 	  for ( i = 0; i < gridsize2; ++i )
 	    if ( remaps[0].grid.grid2_vgpm[i] ) isize++;
 	  gridsize2 = isize;
@@ -759,10 +784,6 @@ void *Remap(void *argument)
 		}
 
 	      memcpy(remaps[r].grid.grid1_mask, imask, remaps[r].grid.grid1_size*sizeof(int));
-	      /*
-	      for ( i = 0; i < gridsize; i++ )
-		if ( remaps[r].grid.grid1_mask[i] ) remaps[r].grid.grid1_mask[i] = imask[i];
-	      */
 
 	      if ( map_type == MAP_TYPE_CONSERV )
 		{
@@ -784,8 +805,22 @@ void *Remap(void *argument)
 	      if ( remaps[r].vars.num_links != remaps[r].vars.max_links )
 		resize_remap_vars(&remaps[r].vars, remaps[r].vars.num_links-remaps[r].vars.max_links);
 
-	      sort_add(remaps[r].vars.num_links, remaps[r].vars.num_wts,
-		       remaps[r].vars.grid2_add, remaps[r].vars.grid1_add, remaps[r].vars.wts);
+	      if ( sort_mode == MERGE_SORT )
+		{ /* 
+		  ** use a combination of the old sort_add and a split and merge approach.
+                  ** The chunk size is determined by MERGE_SORT_LIMIT_SIZE in remaplib.c. 
+		  ** OpenMP parallelism is supported
+		  */   
+		  sort_iter(remaps[r].vars.num_links, remaps[r].vars.num_wts,
+			    remaps[r].vars.grid2_add, remaps[r].vars.grid1_add,
+			    remaps[r].vars.wts, ompNumThreads);
+		}
+	      else
+		{ /* use a pure heap sort without any support of parallelism */
+		  sort_add(remaps[r].vars.num_links, remaps[r].vars.num_wts,
+			   remaps[r].vars.grid2_add, remaps[r].vars.grid1_add,
+			   remaps[r].vars.wts);
+		}
 	      	      
 	      if ( lwrite_remap ) goto WRITE_REMAP;
 
