@@ -22,7 +22,7 @@
 
 #include <ctype.h>
 
-#include "cdi.h"
+#include <cdi.h>
 #include "cdo.h"
 #include "cdo_int.h"
 #include "pstream.h"
@@ -133,7 +133,7 @@ void minmax(int nvals, double *array, int *imiss, double *minval, double *maxval
 
 double *vctFromFile(const char *filename, int *nvct)
 {
-  static char func[] = "vctFromFile";
+  static const char *func = "vctFromFile";
   char line[1024], *pline;
   int num, i = 0;
   int nlevh2, nvct2;
@@ -215,7 +215,7 @@ void vert_sumw(double *sum, double *var3d, long gridsize, long nlevel, double *d
 
 void *Remapeta(void *argument)
 {
-  static char func[] = "Remapeta";
+  static const char *func = "Remapeta";
   int REMAPETA, REMAPETAS, REMAPETAZ;
   int operatorID;
   int streamID1, streamID2;
@@ -519,7 +519,12 @@ void *Remapeta(void *argument)
       if ( tempID != -1 ) cdoAbort("Temperature without humidity unsupported!");
       if ( sqID   != -1 ) cdoAbort("Humidity without temperature unsupported!");
     }
-
+  /*
+  if ( ltq == FALSE )
+    {
+      cdoWarning("Temperature and Humidity not found!");
+    }
+  */
   if ( operatorID == REMAPETAS || operatorID == REMAPETAZ)
     {
       sum1 = (double *) malloc(ngp*sizeof(double));
