@@ -21,7 +21,7 @@
       Replace    replace         Replace variables
 */
 
-#include "cdi.h"
+#include <cdi.h>
 #include "cdo.h"
 #include "cdo_int.h"
 #include "pstream.h"
@@ -31,7 +31,7 @@
 
 void *Replace(void *argument)
 {
-  static char func[] = "Replace";
+  static const char *func = "Replace";
   int varID;
   int varID1, nvars1;
   int varID2, nvars2;
