@@ -24,7 +24,7 @@
 #include <stdio.h>
 #include <math.h>
 
-#include "cdi.h"
+#include <cdi.h>
 #include "cdo.h"
 #include "cdo_int.h"
 #include "pstream.h"
@@ -35,7 +35,7 @@
 
 void *Runpctl(void *argument)
 {
-  static char func[] = "Runpctl";
+  static const char *func = "Runpctl";
   int gridsize;
   int varID;
   int recID;
