@@ -22,7 +22,7 @@
 */
 
 
-#include "cdi.h"
+#include <cdi.h>
 #include "cdo.h"
 #include "cdo_int.h"
 #include "pstream.h"
@@ -31,7 +31,7 @@
 
 void *Seascount(void *argument)
 {
-  static char func[] = "Seascount";
+  static const char *func = "Seascount";
   int operatorID;
   int operfunc;
   int gridsize;
@@ -59,7 +59,7 @@ void *Seascount(void *argument)
   cdoOperatorAdd("seascount", 0, 0, NULL);
 
   operatorID = cdoOperatorID();
-  operfunc = cdoOperatorFunc(operatorID);
+  operfunc = cdoOperatorF1(operatorID);
 
   season_start = get_season_start();
 
