@@ -22,7 +22,7 @@
 */
 
 
-#include "cdi.h"
+#include <cdi.h>
 #include "cdo.h"
 #include "cdo_int.h"
 #include "pstream.h"
@@ -32,7 +32,7 @@
 
 void *Seaspctl(void *argument)
 {
-  static char func[] = "Seaspctl";
+  static const char *func = "Seaspctl";
   int gridsize;
   int vdate1 = 0, vtime1 = 0;
   int vdate2 = 0, vtime2 = 0;
@@ -53,7 +53,7 @@ void *Seaspctl(void *argument)
   double missval;
   field_t **vars1 = NULL;
   field_t field;
-  int pn;
+  double pn;
   HISTOGRAM_SET *hset = NULL;
   int season_start;
 
@@ -62,10 +62,10 @@ void *Seaspctl(void *argument)
   cdoOperatorAdd("seaspctl", func_pctl, 0, NULL);
 
   operatorInputArg("percentile number");
-  pn = atoi(operatorArgv()[0]);
+  pn = atof(operatorArgv()[0]);
       
-  if ( pn < 1 || pn > 99 )
-    cdoAbort("Illegal argument: percentile number %d is not in the range 1..99!", pn);
+  if ( !(pn > 0 && pn < 100) )
+    cdoAbort("Illegal argument: percentile number %g is not in the range 0..100!", pn);
 
   season_start = get_season_start();
 
@@ -81,8 +81,8 @@ void *Seaspctl(void *argument)
   vlistID3 = streamInqVlist(streamID3);
   vlistID4 = vlistDuplicate(vlistID1);
 
-  vlistCompare(vlistID1, vlistID2, func_hrd);
-  vlistCompare(vlistID1, vlistID3, func_hrd);
+  vlistCompare(vlistID1, vlistID2, CMP_HRD);
+  vlistCompare(vlistID1, vlistID3, CMP_HRD);
 
   taxisID1 = vlistInqTaxis(vlistID1);
   taxisID2 = vlistInqTaxis(vlistID2);
