@@ -28,7 +28,7 @@
 */
 
 
-#include "cdi.h"
+#include <cdi.h>
 #include "cdo.h"
 #include "cdo_int.h"
 #include "pstream.h"
@@ -37,7 +37,7 @@
 
 void *Seasstat(void *argument)
 {
-  static char func[] = "Seasstat";
+  static const char *func = "Seasstat";
   int operatorID;
   int operfunc;
   int gridsize;
@@ -75,7 +75,7 @@ void *Seasstat(void *argument)
   cdoOperatorAdd("seasstd",  func_std,  0, NULL);
 
   operatorID = cdoOperatorID();
-  operfunc = cdoOperatorFunc(operatorID);
+  operfunc = cdoOperatorF1(operatorID);
 
   season_start = get_season_start();
   get_season_name(seas_name);
