@@ -22,7 +22,7 @@
       Selbox     selindexbox     Select index box
 */
 
-#include "cdi.h"
+#include <cdi.h>
 #include "cdo.h"
 #include "cdo_int.h"
 #include "pstream.h"
@@ -31,7 +31,7 @@
 static
 int gengrid(int gridID1, int lat1, int lat2, int lon11, int lon12, int lon21, int lon22)
 {
-  static char func[] = "gengrid";  
+  static const char *func = "gengrid";  
   int gridtype, gridID2;
   int nlon1, nlat1;
   int nlon2, nlat2;
@@ -227,7 +227,7 @@ int gengrid(int gridID1, int lat1, int lat2, int lon11, int lon12, int lon21, in
 static
 int gengridcell(int gridID1, int gridsize2, int *cellidx)
 {
-  static char func[] = "gengridcell";  
+  static const char *func = "gengridcell";  
   int gridtype, gridID2;
   int gridsize1;
   int i, k, nv;
@@ -327,10 +327,75 @@ int gengridcell(int gridID1, int gridsize2, int *cellidx)
   return (gridID2);
 }
 
+
+void genlonlatbox(double xlon1, double xlon2, double xlat1, double xlat2,
+		  int nlon1, int nlat1, double *xvals1, double *yvals1,
+		  int *lat1, int *lat2, int *lon11, int *lon12, int *lon21, int *lon22)
+{
+  if ( IS_NOT_EQUAL(xlon1, xlon2) )
+    {
+      xlon2 -= 360 * floor ((xlon2 - xlon1) / 360);
+      if ( IS_EQUAL(xlon1, xlon2) ) xlon2 += 360;
+    }
+  else
+    {
+      xlon2 += 0.00001;
+    }
+  xlon2 -= 360 * floor ((xlon1 - xvals1[0]) / 360);
+  xlon1 -= 360 * floor ((xlon1 - xvals1[0]) / 360);
+  
+  for ( *lon21 = 0; *lon21 < nlon1 && xvals1[*lon21] < xlon1; (*lon21)++ );
+  for ( *lon22 = *lon21; *lon22 < nlon1 && xvals1[*lon22] < xlon2; (*lon22)++ );
+  
+  if ( *lon22 >= nlon1 || xvals1[*lon22] > xlon2 ) (*lon22)--;
+      
+  xlon1 -= 360;
+  xlon2 -= 360;
+
+  for ( *lon11 = 0; xvals1[*lon11] < xlon1; (*lon11)++ );
+  for ( *lon12 = *lon11; *lon12 < nlon1 && xvals1[*lon12] < xlon2; (*lon12)++ );
+
+  (*lon12)--;
+  
+  if ( *lon12 - *lon11 + 1 + *lon22 - *lon21 + 1 <= 0 )
+    cdoAbort("Longitudinal dimension is too small!");
+  
+  if ( yvals1[0] > yvals1[nlat1 - 1] )
+    {
+      if ( xlat1 > xlat2 )
+	{
+	  for ( *lat1 = 0; *lat1 < nlat1 && yvals1[*lat1] > xlat1; (*lat1)++ );
+	  for ( *lat2 = nlat1 - 1; *lat2 && yvals1[*lat2] < xlat2; (*lat2)-- );
+	}
+      else
+	{
+	  for ( *lat1 = 0; *lat1 < nlat1 && yvals1[*lat1] > xlat2; (*lat1)++ );
+	  for ( *lat2 = nlat1 - 1; *lat2 && yvals1[*lat2] < xlat1; (*lat2)-- );
+	}
+    }
+  else
+    {
+      if ( xlat1 < xlat2 )
+	{
+	  for ( *lat1 = 0; *lat1 < nlat1 && yvals1[*lat1] < xlat1; (*lat1)++ );
+	  for ( *lat2 = nlat1 - 1; *lat2 && yvals1[*lat2] > xlat2; (*lat2)-- );
+	}
+      else
+	{
+	  for ( *lat1 = 0; *lat1 < nlat1 && yvals1[*lat1] < xlat2; (*lat1)++ );
+	  for ( *lat2 = nlat1 - 1; *lat2 && yvals1[*lat2] > xlat1; (*lat2)-- );
+	}
+    }
+  
+  if ( *lat2 - *lat1 + 1 <= 0 )
+    cdoAbort("Latitudinal dimension is too small!");
+}
+
+
 static
 int genlonlatgrid(int gridID1, int *lat1, int *lat2, int *lon11, int *lon12, int *lon21, int *lon22)
 {
-  static char func[] = "genlonlatgrid";  
+  static const char *func = "genlonlatgrid";  
   int ilon, ilat;
   int nlon1, nlat1;
   int gridtype, gridID2;
@@ -472,80 +537,21 @@ int genlonlatgrid(int gridID1, int *lat1, int *lat2, int *lon11, int *lon12, int
 	  *lat2 = iymax;
 	  *lon21 = ixmin;
 	  *lon22 = ixmax;
-	}
-      
-      if ( cdoVerbose )
-	fprintf(stderr, " ixmin=%d, ixmax=%d, iymin=%d, iymax=%d\n", *lon21, *lon22, *lat1, *lat2);
-      
+	}      
+
+      if ( *lat2 - *lat1 + 1 <= 0 )
+	cdoAbort("Latitudinal dimension is too small!");
     }
   else
     {
       for ( ilat = 0; ilat < nlat1; ilat++ ) yvals1[ilat] *= yfact;
       for ( ilon = 0; ilon < nlon1; ilon++ ) xvals1[ilon] *= xfact;
 
-      if ( IS_NOT_EQUAL(xlon1, xlon2) )
-	{
-	  xlon2 -= 360 * floor ((xlon2 - xlon1) / 360);
-	  if ( IS_EQUAL(xlon1, xlon2) ) xlon2 += 360;
-	}
-      else
-	{
-	  xlon2 += 0.00001;
-	}
-      xlon2 -= 360 * floor ((xlon1 - xvals1[0]) / 360);
-      xlon1 -= 360 * floor ((xlon1 - xvals1[0]) / 360);
-
-      for ( *lon21 = 0; *lon21 < nlon1 && xvals1[*lon21] < xlon1; (*lon21)++ );
-      for ( *lon22 = *lon21; *lon22 < nlon1 && xvals1[*lon22] < xlon2; (*lon22)++ );
-
-      if ( *lon22 >= nlon1 ) (*lon22)--;
-
-      xlon1 -= 360;
-      xlon2 -= 360;
-
-      for ( *lon11 = 0; xvals1[*lon11] < xlon1; (*lon11)++ );
-      for ( *lon12 = *lon11; *lon12 < nlon1 && xvals1[*lon12] < xlon2; (*lon12)++ );
-
-      (*lon12)--;
-
-      if ( *lon12 - *lon11 + 1 + *lon22 - *lon21 + 1 <= 0 )
-	cdoAbort("Longitudinal dimension is too small!");
-
-      if ( yvals1[0] > yvals1[nlat1 - 1] )
-	{
-	  if ( xlat1 > xlat2 )
-	    {
-	      for ( *lat1 = 0; *lat1 < nlat1 && yvals1[*lat1] > xlat1; (*lat1)++ );
-	      for ( *lat2 = nlat1 - 1; *lat2 && yvals1[*lat2] < xlat2; (*lat2)-- );
-	    }
-	  else
-	    {
-	      for ( *lat1 = 0; *lat1 < nlat1 && yvals1[*lat1] > xlat2; (*lat1)++ );
-	      for ( *lat2 = nlat1 - 1; *lat2 && yvals1[*lat2] < xlat1; (*lat2)-- );
-	    }
-	}
-      else
-	{
-	  if ( xlat1 < xlat2 )
-	    {
-	      for ( *lat1 = 0; *lat1 < nlat1 && yvals1[*lat1] < xlat1; (*lat1)++ );
-	      for ( *lat2 = nlat1 - 1; *lat2 && yvals1[*lat2] > xlat2; (*lat2)-- );
-	    }
-	  else
-	    {
-	      for ( *lat1 = 0; *lat1 < nlat1 && yvals1[*lat1] < xlat2; (*lat1)++ );
-	      for ( *lat2 = nlat1 - 1; *lat2 && yvals1[*lat2] > xlat1; (*lat2)-- );
-	    }
-	}
+      genlonlatbox(xlon1, xlon2, xlat1, xlat2,
+		   nlon1, nlat1, xvals1, yvals1,
+		   lat1, lat2, lon11, lon12, lon21, lon22);
     }
 
-  if ( *lat2 - *lat1 + 1 <= 0 )
-    cdoAbort("Latitudinal dimension is too small!");
-
-  /*
-  if ( (*lon22 - *lon21 + 1 <= 0)  && (*lon12 - *lon11 + 1 <= 0)  )
-    cdoAbort("Longitudinal dimension is too small!");
-  */
   free(xvals1);
   free(yvals1);
 
@@ -558,7 +564,7 @@ int genlonlatgrid(int gridID1, int *lat1, int *lat2, int *lon11, int *lon12, int
 static
 int gencellgrid(int gridID1, int *gridsize2, int **cellidx)
 {
-  static char func[] = "gencellgrid";  
+  static const char *func = "gencellgrid";  
   int gridtype, gridID2;
   double *xvals1, *yvals1;
   double xlon1, xlon2, xlat1, xlat2, x, xval, yval;
@@ -746,7 +752,7 @@ void window_cell(double *array1, int gridID1, double *array2, int gridsize2, int
 
 void *Selbox(void *argument)
 {
-  static char func[] = "Selbox";
+  static const char *func = "Selbox";
   int SELLONLATBOX, SELINDEXBOX;
   int operatorID;
   int streamID1, streamID2;
@@ -835,6 +841,13 @@ void *Selbox(void *argument)
 	}
     }
 
+  if ( cdoVerbose )
+    {
+      if ( gridtype != GRID_CELL )
+	cdoPrint("idx1,idx2,idy1,idy2: %d,%d,%d,%d",
+		 sbox[0].lon21+1, sbox[0].lon22+1, sbox[0].lat1+1, sbox[0].lat2+1);
+    }
+
   streamID2 = streamOpenWrite(cdoStreamName(1), cdoFiletype());
   if ( streamID2 < 0 ) cdiError(streamID2, "Open failed on %s", cdoStreamName(1));
 
