@@ -21,7 +21,7 @@
       Select      select         Select fields
 */
 
-#include "cdi.h"
+#include <cdi.h>
 #include "cdo.h"
 #include "cdo_int.h"
 #include "pstream.h"
@@ -124,7 +124,7 @@ typedef struct
 static
 void pml_init(pml_t *pml, const char *name)
 {
-  static char func[] = "pml_init";
+  static const char *func = "pml_init";
   pml->size = 0;
   pml->dis  = 1;
   pml->name = strdup(name);
@@ -133,7 +133,7 @@ void pml_init(pml_t *pml, const char *name)
 
 pml_t *pmlNew(const char *name)
 {
-  static char func[] = "pmlNew";
+  static const char *func = "pmlNew";
   pml_t *pml;
 
   pml = (pml_t *) malloc(sizeof(pml_t));
@@ -180,7 +180,7 @@ void pmlPrint(pml_t *pml)
 
 int pmlAdd(pml_t *pml, const char *name, int type, int dis, void *ptr, size_t size)
 {
-  static char func[] = "pmlAdd";
+  static const char *func = "pmlAdd";
   pml_entry_t *pml_entry;
   int entry = 0;
 
@@ -233,7 +233,7 @@ int pmlNum(pml_t *pml, const char *name)
 
 int pml_add_entry(pml_entry_t *entry, char *arg)
 {
-  static char func[] = "pml_add_entry";
+  static const char *func = "pml_add_entry";
   int status = 0;
 
   if ( entry->type == PML_INT )
@@ -287,7 +287,7 @@ void pmlProcess(pml_entry_t *entry, int argc, char **argv)
 
 int pmlRead(pml_t *pml, int argc, char **argv)
 {
-  static char func[] = "pmlRead";
+  static const char *func = "pmlRead";
   pml_entry_t *entry = NULL;
   pml_entry_t *pentry[MAX_PML_ENTRY];
   int params[MAX_PML_ENTRY];
@@ -649,8 +649,8 @@ void *Select(void *argument)
 	}
       else
 	{
-	  vlistCompare(vlistID0, vlistID1, func_sft);
-	  /* vlistCompare(vlistID1, vlistID2, func_hrd); */
+	  vlistCompare(vlistID0, vlistID1, CMP_SFT);
+	  /* vlistCompare(vlistID1, vlistID2, CMP_HRD); */
 	}
 
       tsID1 = 0;
