@@ -15,7 +15,7 @@
   GNU General Public License for more details.
 */
 
-#include "cdi.h"
+#include <cdi.h>
 #include "cdo.h"
 #include "cdo_int.h"
 #include "pstream.h"
@@ -23,7 +23,7 @@
 
 void *Seloperator(void *argument)
 {
-  static char func[] = "Seloperator";
+  static const char *func = "Seloperator";
   int streamID1, streamID2 = CDI_UNDEFID;
   int nrecs;
   int tsID, recID, varID, levelID;
