@@ -21,7 +21,7 @@
       Selrec     selrec          Select records
 */
 
-#include "cdi.h"
+#include <cdi.h>
 #include "cdo.h"
 #include "cdo_int.h"  /* processSelf */
 #include "pstream.h"
