@@ -35,7 +35,7 @@
 
 #include <ctype.h>  /* isdigit */
 
-#include "cdi.h"
+#include <cdi.h>
 #include "cdo.h"
 #include "cdo_int.h"
 #include "pstream.h"
