@@ -24,7 +24,7 @@
 
 #include <ctype.h>
 
-#include "cdi.h"
+#include <cdi.h>
 #include "cdo.h"
 #include "cdo_int.h"
 #include "pstream.h"
@@ -32,7 +32,7 @@
 
 void *Setgatt(void *argument)
 {
-  static char func[] = "Setgatt";
+  static const char *func = "Setgatt";
   int SETGATT, SETGATTS;
   int operatorID;
   int streamID1, streamID2 = CDI_UNDEFID;
