@@ -34,7 +34,7 @@
 int isnan(const double x);
 #endif
 
-#include "cdi.h"
+#include <cdi.h>
 #include "cdo.h"
 #include "cdo_int.h"
 #include "pstream.h"
@@ -42,7 +42,7 @@ int isnan(const double x);
 
 void *Setmiss(void *argument)
 {
-  static char func[] = "Setmiss";
+  static const char *func = "Setmiss";
   int SETMISSVAL, SETCTOMISS, SETMISSTOC, SETRTOMISS, SETVRANGE;
   int operatorID;
   int streamID1, streamID2;
@@ -121,7 +121,7 @@ void *Setmiss(void *argument)
 
       nvars = vlistNvars(vlistID2);
       for ( varID = 0; varID < nvars; varID++ )
-	vlistDefAttFlt(vlistID2, varID, "valid_range", 2, range);
+	vlistDefAttFlt(vlistID2, varID, "valid_range", DATATYPE_FLT64, 2, range);
     }
 
   streamID2 = streamOpenWrite(cdoStreamName(1), cdoFiletype());
