@@ -21,7 +21,7 @@
       Setzaxis   setzaxis        Set zaxis
 */
 
-#include "cdi.h"
+#include <cdi.h>
 #include "cdo.h"
 #include "cdo_int.h"
 #include "pstream.h"
@@ -29,7 +29,7 @@
 
 void *Setzaxis(void *argument)
 {
-  static char func[] = "Setzaxis";
+  static const char *func = "Setzaxis";
   int SETZAXIS;
   int operatorID;
   int streamID1, streamID2 = CDI_UNDEFID;
