@@ -21,7 +21,7 @@
       Sinfo      sinfo           Short dataset information
 */
 
-#include "cdi.h"
+#include <cdi.h>
 #include "cdo.h"
 #include "cdo_int.h"
 #include "pstream.h"
