@@ -22,14 +22,14 @@
 */
 
 
-#include "cdi.h"
+#include <cdi.h>
 #include "cdo.h"
 #include "cdo_int.h"
 #include "pstream.h"
 
 void *Smooth9(void *argument)
 {
-  static char func[] = "Smooth9";
+  static const char *func = "Smooth9";
   int operatorID;
   int operfunc;
   int streamID1, streamID2;
@@ -56,7 +56,7 @@ void *Smooth9(void *argument)
   cdoOperatorAdd("smooth9",   0,   0, NULL);
  
   operatorID = cdoOperatorID();
-  operfunc = cdoOperatorFunc(operatorID);
+  operfunc = cdoOperatorF1(operatorID);
 
   streamID1 = streamOpenRead(cdoStreamName(0));
   if ( streamID1 < 0 ) cdiError(streamID1, "Open failed on %s", cdoStreamName(0));
