@@ -21,7 +21,7 @@
       Sort sortcode  Sort by code number
 */
 
-#include "cdi.h"
+#include <cdi.h>
 #include "cdo.h"
 #include "cdo_int.h"
 #include "pstream.h"
@@ -95,7 +95,7 @@ int findrec(recinfo_t *recInfo[], int nrecords, int varID, int levelID)
 
 void *Sort(void *argument)
 {
-  static char func[] = "Sort";
+  static const char *func = "Sort";
   int SORTCODE, SORTNAME, SORTLEVEL;
   int operatorID;
   int streamID1, streamID2;
