@@ -26,7 +26,7 @@
       Spectral   spcut           Cut spectral wave number
 */
 
-#include "cdi.h"
+#include <cdi.h>
 #include "cdo.h"
 #include "cdo_int.h"
 #include "pstream.h"
@@ -38,7 +38,7 @@
 
 void *Spectral(void *argument)
 {
-  static char func[] = "Spectral";
+  static const char *func = "Spectral";
   int GP2SP, GP2SPL, SP2GP, SP2GPL, SP2SP, SPCUT;
   int operatorID;
   int streamID1, streamID2;
