@@ -22,7 +22,7 @@
 */
 
 
-#include "cdi.h"
+#include <cdi.h>
 #include "cdo.h"
 #include "cdo_int.h"
 #include "pstream.h"
@@ -151,7 +151,7 @@ void spectrum(int nrec, double *data, double *spectrum, double *real, double *im
 
 void *Spectrum(void *argument)
 {
-  static char func[] = "Spectrum";
+  static const char *func = "Spectrum";
   int gridsize;
   int nrecs;
   int gridID, varID, levelID, recID;
