@@ -21,7 +21,7 @@
       Splitsel   splitsel        Split time selection
 */
 
-#include "cdi.h"
+#include <cdi.h>
 #include "cdo.h"
 #include "cdo_int.h"
 #include "pstream.h"
@@ -29,7 +29,7 @@
 
 void *Splitsel(void *argument)
 {
-  static char func[] = "Splitsel";
+  static const char *func = "Splitsel";
 
   /* from Selstat.c */
   int operatorID;
@@ -61,7 +61,7 @@ void *Splitsel(void *argument)
   cdoOperatorAdd("splitsel",  0,  0, NULL);
 
   operatorID = cdoOperatorID();
-  operfunc = cdoOperatorFunc(operatorID);
+  operfunc = cdoOperatorF1(operatorID);
 
   if ( UNCHANGED_RECORD ) lcopy = TRUE;
 
