@@ -24,7 +24,7 @@
       Splittime  splitseas       Split seasons
 */
 
-#include "cdi.h"
+#include <cdi.h>
 #include "cdo.h"
 #include "cdo_int.h"
 #include "pstream.h"
@@ -35,7 +35,7 @@
 
 void *Splittime(void *argument)
 {
-  static char func[] = "Splittime";
+  static const char *func = "Splittime";
   int SPLITHOUR, SPLITDAY, SPLITMON, SPLITSEAS;
   int operatorID;
   int operfunc, operintval;
@@ -67,8 +67,8 @@ void *Splittime(void *argument)
   SPLITSEAS = cdoOperatorAdd("splitseas", func_date,   100, NULL);
 
   operatorID = cdoOperatorID();
-  operfunc   = cdoOperatorFunc(operatorID);
-  operintval = cdoOperatorIntval(operatorID);
+  operfunc   = cdoOperatorF1(operatorID);
+  operintval = cdoOperatorF2(operatorID);
 
   if ( UNCHANGED_RECORD ) lcopy = TRUE;
 
