@@ -21,7 +21,7 @@
      Splittime  splityear       Split years
 */
 
-#include "cdi.h"
+#include <cdi.h>
 #include "cdo.h"
 #include "cdo_int.h"
 #include "pstream.h"
@@ -31,7 +31,7 @@
 
 void *Splityear(void *argument)
 {
-  static char func[] = "Splityear";
+  static const char *func = "Splityear";
   int nchars;
   int streamID1, streamID2 = -1;
   int varID;
