@@ -15,7 +15,7 @@
   GNU General Public License for more details.
 */
 
-#include "cdi.h"
+#include <cdi.h>
 #include "cdo.h"
 #include "cdo_int.h"
 #include "pstream.h"
@@ -23,7 +23,7 @@
 
 void *Template1(void *argument)
 {
-  static char func[] = "Template1";
+  static const char *func = "Template1";
   int streamID1, streamID2 = CDI_UNDEFID;
   int nrecs;
   int tsID, recID, varID, levelID;
@@ -100,7 +100,7 @@ void *Template1(void *argument)
 
 void *Template2(void *argument)
 {
-  static char func[] = "Template2";
+  static const char *func = "Template2";
   int streamID1, streamID2 = CDI_UNDEFID;
   int nrecs;
   int tsID, recID, varID, levelID;
