@@ -28,7 +28,7 @@
 */
 
 
-#include "cdi.h"
+#include <cdi.h>
 #include "cdo.h"
 #include "cdo_int.h"
 #include "pstream.h"
@@ -36,7 +36,7 @@
 
 void *Timselstat(void *argument)
 {
-  static char func[] = "Timselstat";
+  static const char *func = "Timselstat";
   int operatorID;
   int operfunc;
   int gridsize;
@@ -69,7 +69,7 @@ void *Timselstat(void *argument)
   cdoOperatorAdd("timselstd",  func_std,  0, NULL);
 
   operatorID = cdoOperatorID();
-  operfunc = cdoOperatorFunc(operatorID);
+  operfunc = cdoOperatorF1(operatorID);
 
   operatorInputArg("nsets <noffset <nskip>>");
 
