@@ -26,7 +26,7 @@
 #  include <omp.h>
 #endif
 
-#include "cdi.h"
+#include <cdi.h>
 #include "cdo.h"
 #include "cdo_int.h"
 #include "pstream.h"
@@ -52,7 +52,7 @@ int cmpdarray(const void *s1, const void *s2)
 
 void *Timsort(void *argument)
 {
-  static char func[] = "Timsort";
+  static const char *func = "Timsort";
   int gridsize;
   int nrecs;
   int gridID, varID, levelID, recID;
