@@ -22,7 +22,7 @@
         Timstat3        meandiff2test
 */
 
-#include "cdi.h"
+#include <cdi.h>
 #include "cdo.h"
 #include "cdo_int.h"
 #include "pstream.h"
@@ -35,7 +35,7 @@
 
 void *Timstat3(void *argument)
 {
-  static char func[] = "Timstat3";
+  static const char *func = "Timstat3";
   int VARQUOT2TEST, MEANDIFF2TEST;
   int operatorID;
   int *streamID, streamID3;
@@ -94,7 +94,7 @@ void *Timstat3(void *argument)
       if ( is > 0 )
 	{
 	  vlistID2 = streamInqVlist(streamID[is]);
-	  vlistCompare(vlistID[0], vlistID2, func_sft);
+	  vlistCompare(vlistID[0], vlistID2, CMP_SFT);
 	}
     }
 
@@ -283,7 +283,7 @@ void *Timstat3(void *argument)
 	      if ( !DBL_IS_EQUAL(temp0, missval1) && temp0 < 0 ) /* This is possible because */
 		temp0 = 0;	                                 /* of rounding errors       */
 
-	      stddev_estimator = ROOT(DIV(temp0, deg_of_freedom));
+	      stddev_estimator = SQRT(DIV(temp0, deg_of_freedom));
 	      mean_estimator = -rconst;
 	      for ( j = 0; j < n_in; j++ )
 		{
@@ -301,7 +301,7 @@ void *Timstat3(void *argument)
 					     var_factor[j]), fnvals));
 		}
 
-	      norm = ROOT(temp1);
+	      norm = SQRT(temp1);
 	      
 	      temp2 = DIV(DIV(mean_estimator, norm), stddev_estimator);
 	      fractil = deg_of_freedom < 1 ? missval1 :
