@@ -21,7 +21,7 @@
       Tinfo      tinfo           Time information
 */
 
-#include "cdi.h"
+#include <cdi.h>
 #include "cdo.h"
 #include "cdo_int.h"
 #include "pstream.h"
