@@ -22,7 +22,7 @@
 */
 
 
-#include "cdi.h"
+#include <cdi.h>
 #include "cdo.h"
 #include "cdo_int.h"
 #include "pstream.h"
@@ -30,7 +30,7 @@
 
 void transxy(int gridID, double *array1, double *array2)
 {
-  static char func[] = "transxy";
+  static const char *func = "transxy";
   int i, j;
   int nx, ny;
   double **a2D1, **a2D2;
@@ -55,7 +55,7 @@ void transxy(int gridID, double *array1, double *array2)
 
 void *Transpose(void *argument)
 {
-  static char func[] = "Transpose";
+  static const char *func = "Transpose";
   int streamID1, streamID2;
   int gridsize;
   int ngrids, index;
