@@ -22,7 +22,7 @@
 */
 
 
-#include "cdi.h"
+#include <cdi.h>
 #include "cdo.h"
 #include "cdo_int.h"
 #include "pstream.h"
@@ -30,7 +30,7 @@
 
 void *Trend(void *argument)
 {
-  static char func[] = "Trend";
+  static const char *func = "Trend";
   int gridsize;
   int vdate = 0, vtime = 0;
   int nrecs, nrecords;
