@@ -21,7 +21,7 @@
 */
 
 
-#include "cdi.h"
+#include <cdi.h>
 #include "cdo.h"
 #include "cdo_int.h"
 #include "pstream.h"
@@ -54,7 +54,7 @@ void trms(field_t field1, field_t field2, double *dp, field_t *field3)
 	rsumw = ADD(rsumw, wp);
       }
 
-  ravg = ROOT(DIV(rsum, rsumw));
+  ravg = SQRT(DIV(rsum, rsumw));
 
   if ( DBL_IS_EQUAL(ravg, missval1) ) rnmiss++;
 
@@ -64,7 +64,7 @@ void trms(field_t field1, field_t field2, double *dp, field_t *field3)
 
 void *Trms(void *argument)
 {
-  static char func[] = "Trms";
+  static const char *func = "Trms";
   int streamID1, streamID2, streamID3;
   int vlistID1, vlistID2, vlistID3;
   int gridID1, gridID3, lastgrid = -1;
