@@ -22,7 +22,7 @@
       Vardup     parmul          Multiply parameters
 */
 
-#include "cdi.h"
+#include <cdi.h>
 #include "cdo.h"
 #include "cdo_int.h"
 #include "pstream.h"
@@ -30,7 +30,7 @@
 
 void *Vardup(void *argument)
 {
-  static char func[] = "Vardup";
+  static const char *func = "Vardup";
   int PARDUP, PARMUL;
   int operatorID;
   int streamID1, streamID2;
