@@ -22,7 +22,7 @@
       Vargen     random          Field with random values
 */
 
-#include "cdi.h"
+#include <cdi.h>
 #include "cdo.h"
 #include "cdo_int.h"
 #include "pstream.h"
@@ -35,9 +35,17 @@
 #endif
 
 
+#if defined(WITH_ETOPO)
+  static double etopo_scale = 3;
+  static const short etopo[] = {
+#include "etopo.h"
+  };
+#endif
+
+
 void *Vargen(void *argument)
 {
-  static char func[] = "Vargen";
+  static const char *func = "Vargen";
   int RANDOM, CONST, TOPO, FOR;
   int operatorID;
   int streamID;
@@ -51,12 +59,6 @@ void *Vargen(void *argument)
   double rval, rstart = 0, rstop = 0, rinc = 0;
   double rconst = 0;
   double *array;
-#if defined(WITH_ETOPO)
-  double etopo_scale = 3;
-  static const short etopo[] = {
-#include "etopo.h"
-  };
-#endif
 
   cdoInitialize(argument);
 
@@ -110,6 +112,7 @@ void *Vargen(void *argument)
     }
   else if ( operatorID == FOR )
     {
+      double lon = 0, lat = 0;
       operatorInputArg(cdoOperatorEnter(operatorID));
       if ( operatorArgc() < 2 ) cdoAbort("Too few arguments!");
       if ( operatorArgc() > 3 ) cdoAbort("Too many arguments!");
@@ -123,9 +126,11 @@ void *Vargen(void *argument)
 
       if ( DBL_IS_EQUAL(rinc, 0.0) ) cdoAbort("Increment is zero!");
 
-      gridID = gridCreate(GRID_GENERIC, 1);
+      gridID = gridCreate(GRID_LONLAT, 1);
       gridDefXsize(gridID, 1);
       gridDefYsize(gridID, 1);
+      gridDefXvals(gridID, &lon);
+      gridDefYvals(gridID, &lat);
     }
 
 
