@@ -25,7 +25,7 @@
 
 #include <ctype.h>
 
-#include "cdi.h"
+#include <cdi.h>
 #include "cdo.h"
 #include "cdo_int.h"
 #include "pstream.h"
@@ -36,7 +36,7 @@
 
 void *Vertint(void *argument)
 {
-  static char func[] = "Vertint";
+  static const char *func = "Vertint";
   int ML2PL, ML2HL, ML2PLX, ML2HLX;
   int ML2PL_LP, ML2HL_LP, ML2PLX_LP, ML2HLX_LP;
   int operatorID;
@@ -92,8 +92,8 @@ void *Vertint(void *argument)
   ML2HLX_LP = cdoOperatorAdd("ml2hlx_lp", func_hl, type_log, "height levels in meter");
 
   operatorID = cdoOperatorID();
-  operfunc = cdoOperatorFunc(operatorID);
-  opertype = cdoOperatorIntval(operatorID);
+  operfunc = cdoOperatorF1(operatorID);
+  opertype = cdoOperatorF2(operatorID);
 
   if ( operatorID == ML2PL || operatorID == ML2HL || operatorID == ML2PL_LP || operatorID == ML2HL_LP )
     {
