@@ -28,7 +28,7 @@
 */
 
 
-#include "cdi.h"
+#include <cdi.h>
 #include "cdo.h"
 #include "cdo_int.h"
 #include "pstream.h"
@@ -37,7 +37,7 @@
 
 void *Vertstat(void *argument)
 {
-  static char func[] = "Vertstat";
+  static const char *func = "Vertstat";
   int operatorID;
   int operfunc;
   int streamID1, streamID2;
@@ -65,7 +65,7 @@ void *Vertstat(void *argument)
   cdoOperatorAdd("vertstd",  func_std,  0, NULL);
 
   operatorID = cdoOperatorID();
-  operfunc = cdoOperatorFunc(operatorID);
+  operfunc = cdoOperatorF1(operatorID);
 
   streamID1 = streamOpenRead(cdoStreamName(0));
   if ( streamID1 < 0 ) cdiError(streamID1, "Open failed on %s", cdoStreamName(0));
