@@ -23,7 +23,7 @@
 
 #include <ctype.h>
 
-#include "cdi.h"
+#include <cdi.h>
 #include "cdo.h"
 #include "cdo_int.h"
 #include "pstream.h"
@@ -35,7 +35,7 @@
 
 void *Vertwind(void *argument)
 {
-  static char func[] = "Vertwind";
+  static const char *func = "Vertwind";
   int streamID1, streamID2;
   int vlistID1, vlistID2;
   int taxisID1, taxisID2;
