@@ -24,7 +24,7 @@
                                  velocity potential and stream function
 */
 
-#include "cdi.h"
+#include <cdi.h>
 #include "cdo.h"
 #include "cdo_int.h"
 #include "pstream.h"
@@ -34,7 +34,7 @@
 
 void *Wind(void *argument)
 {
-  static char func[] = "Wind";
+  static const char *func = "Wind";
   int UV2DV, UV2DVL, DV2UV, DV2UVL, DV2PS;
   int operatorID;
   int streamID1, streamID2;
