@@ -21,7 +21,7 @@
       Writerandom writerandom
 */
 
-#include "cdi.h"
+#include <cdi.h>
 #include "cdo.h"
 #include "cdo_int.h"
 #include "pstream.h"
@@ -29,7 +29,7 @@
 
 void *Writerandom(void *argument)
 {
-  static char func[] = "Writerandom";
+  static const char *func = "Writerandom";
   int streamID1, streamID2;
   int vlistID1, vlistID2;
   int gridsize;
