@@ -25,7 +25,7 @@
 #include <stdio.h>
 #include <math.h>
 
-#include "cdi.h"
+#include <cdi.h>
 #include "cdo.h"
 #include "cdo_int.h"
 #include "pstream.h"
@@ -37,7 +37,7 @@
 
 void *Ydaypctl(void *argument)
 {
-  static char func[] = "Ydaypctl";
+  static const char *func = "Ydaypctl";
   int gridsize;
   int varID;
   int recID;
@@ -59,17 +59,17 @@ void *Ydaypctl(void *argument)
   double missval;
   field_t **vars1[NDAY];
   field_t field;
-  int pn;
+  double pn;
   HISTOGRAM_SET *hsets[NDAY];
 
   cdoInitialize(argument);
   cdoOperatorAdd("ydaypctl", func_pctl, 0, NULL);
 
   operatorInputArg("percentile number");
-  pn = atoi(operatorArgv()[0]);
+  pn = atof(operatorArgv()[0]);
       
-  if ( pn < 1 || pn > 99 )
-    cdoAbort("Illegal argument: percentile number %d is not in the range 1..99!", pn);
+  if ( !(pn > 0 && pn < 100) )
+    cdoAbort("Illegal argument: percentile number %g is not in the range 0..100!", pn);
 
   for ( dayoy = 0; dayoy < NDAY; dayoy++ )
     {
@@ -90,8 +90,8 @@ void *Ydaypctl(void *argument)
   vlistID3 = streamInqVlist(streamID3);
   vlistID4 = vlistDuplicate(vlistID1);
 
-  vlistCompare(vlistID1, vlistID2, func_hrd);
-  vlistCompare(vlistID1, vlistID3, func_hrd);
+  vlistCompare(vlistID1, vlistID2, CMP_HRD);
+  vlistCompare(vlistID1, vlistID3, CMP_HRD);
 
   taxisID1 = vlistInqTaxis(vlistID1);
   taxisID2 = vlistInqTaxis(vlistID2);
