@@ -31,7 +31,7 @@
 #include <stdio.h>
 #include <math.h>
 
-#include "cdi.h"
+#include <cdi.h>
 #include "cdo.h"
 #include "cdo_int.h"
 #include "pstream.h"
@@ -43,7 +43,7 @@
 
 void *Ydaystat(void *argument)
 {
-  static char func[] = "Ydaystat";
+  static const char *func = "Ydaystat";
   int operatorID;
   int operfunc;
   int gridsize;
@@ -79,7 +79,7 @@ void *Ydaystat(void *argument)
   cdoOperatorAdd("ydaystd",  func_std,  0, NULL);
 
   operatorID = cdoOperatorID();
-  operfunc = cdoOperatorFunc(operatorID);
+  operfunc = cdoOperatorF1(operatorID);
 
   for ( dayoy = 0; dayoy < NDAY; dayoy++ )
     {
