@@ -21,7 +21,7 @@
       Ydrunpctl    ydrunpctl         Multi-year daily running percentiles
 */
 
-#include "cdi.h"
+#include <cdi.h>
 #include "cdo.h"
 #include "cdo_int.h"
 #include "pstream.h"
@@ -35,7 +35,7 @@
 
 void *Ydrunpctl(void *argument)
 {
-  static char func[] = "Ydrunpctl";
+  static const char *func = "Ydrunpctl";
   int gridsize;
   int varID;
   int recID;
@@ -61,7 +61,7 @@ void *Ydrunpctl(void *argument)
   int nsets[NDAY];
   int year, month, day, dayoy;
   field_t field;
-  int pn;
+  double pn;
   HISTOGRAM_SET *hsets[NDAY];
     
   cdoInitialize(argument);
@@ -69,11 +69,11 @@ void *Ydrunpctl(void *argument)
 
   operatorInputArg("percentile number, number of timesteps");
   operatorCheckArgc(2);
-  pn     = atoi(operatorArgv()[0]);
+  pn     = atof(operatorArgv()[0]);
   ndates = atoi(operatorArgv()[1]);
 
-  if ( pn < 1 || pn > 99 )
-    cdoAbort("Illegal argument: percentile number %d is not in the range 1..99!", pn);
+  if ( !(pn > 0 && pn < 100) )
+    cdoAbort("Illegal argument: percentile number %g is not in the range 0..100!", pn);
   
   for ( dayoy = 0; dayoy < NDAY; dayoy++ )
     {
@@ -94,8 +94,8 @@ void *Ydrunpctl(void *argument)
   vlistID3 = streamInqVlist(streamID3);
   vlistID4 = vlistDuplicate(vlistID1);
 
-  vlistCompare(vlistID1, vlistID2, func_hrd);
-  vlistCompare(vlistID1, vlistID3, func_hrd);
+  vlistCompare(vlistID1, vlistID2, CMP_HRD);
+  vlistCompare(vlistID1, vlistID3, CMP_HRD);
 
   taxisID1 = vlistInqTaxis(vlistID1);
   taxisID2 = vlistInqTaxis(vlistID2);
