@@ -29,7 +29,7 @@
 */
 
 
-#include "cdi.h"
+#include <cdi.h>
 #include "cdo.h"
 #include "cdo_int.h"
 #include "grid.h"
@@ -39,7 +39,7 @@
 
 void *Zonstat(void *argument)
 {
-  static char func[] = "Zonstat";
+  static const char *func = "Zonstat";
   int operatorID;
   int operfunc;
   int streamID1, streamID2;
@@ -71,7 +71,7 @@ void *Zonstat(void *argument)
   /* QR */
 
   operatorID = cdoOperatorID();
-  operfunc = cdoOperatorFunc(operatorID);
+  operfunc = cdoOperatorF1(operatorID);
 
   /* RQ */
   if ( operfunc == func_pctl )
