@@ -17,9 +17,10 @@
 
 #include <assert.h>
 
-#include "cdi.h"
+#include <cdi.h>
 #include "cdo.h"
 #include "cdo_int.h"
+#include "pstream.h"
 #include "ecautil.h"
 
 
@@ -146,7 +147,7 @@ unsigned long day_of_year(int date)
  */  
 static void count(field_t *field1, const field_t *field2, double mode)
 {
-  static const char func[] = "count";
+  static const char *func = "count";
   int   i, len;
   const int     grid1    = field1->grid;
   const int     nmiss1   = field1->nmiss;
@@ -231,7 +232,7 @@ static void count(field_t *field1, const field_t *field2, double mode)
  */  
 static void selcomp(field_t *field1, const field_t *field2, int (*compare)(double, double))
 {
-  static const char func[] = "selcomp";
+  static const char *func = "selcomp";
   int   i, len;
   const int     grid1    = field1->grid;
   const int     nmiss1   = field1->nmiss;
@@ -371,7 +372,7 @@ void farnum3(field_t *field1, field_t field2, double n)
 
 void farsel(field_t *field1, field_t field2)
 {
-  static const char func[] = "farsel";
+  static const char *func = "farsel";
   int   i, len;
   const int     grid1    = field1->grid;
   const double  missval1 = field1->missval;
@@ -478,7 +479,7 @@ void farselgtc(field_t *field, double c)
 void updateHist(field_t *field[2], int nlevels, int gridsize, double *yvals, int onlyNorth)
 {
   int levelID,i;
-  
+
   for ( levelID = 0; levelID < nlevels; levelID++ )
     for ( i = 0; i < gridsize; i++ )
       if ( onlyNorth )
@@ -491,50 +492,49 @@ void updateHist(field_t *field[2], int nlevels, int gridsize, double *yvals, int
 }
 
 void adjustEndDate(int nlevels, int gridsize, double *yvals, double missval, int ovdate,
-                field_t *startDateWithHist[2], field_t *endDateWithHist[2]) 
+                field_t *startDateWithHist[2], field_t *endDateWithHist[2])
 {
   int levelID, i, ovdateSouth;
-  
+
   ovdateSouth = MIN(cdiEncodeDate(ovdate/10000,6,30),ovdate);
 
   for ( levelID = 0; levelID < nlevels; levelID++ )
+  {
+    for ( i = 0; i < gridsize; i++ )
     {
-      for ( i = 0; i < gridsize; i++ )
-        {
-          /* dictinct between northern and southern sphere */
-          /* start with north */
-          if ( yvals[i] >= 0 )
-	    {
-	      if ( DBL_IS_EQUAL(startDateWithHist[0][levelID].ptr[i], missval) ) {
-		endDateWithHist[0][levelID].ptr[i] = missval;
-		continue;
-	      }
-	    
-	      if ( DBL_IS_EQUAL(endDateWithHist[0][levelID].ptr[i], missval) ) {
-		endDateWithHist[0][levelID].ptr[i] = ovdate;
-	      }
-	    }
-          else
-	    {
-	      if ( DBL_IS_EQUAL(startDateWithHist[1][levelID].ptr[i], missval) ) {
-		endDateWithHist[0][levelID].ptr[i] = missval;
-		continue;
-	      }
-	      if ( DBL_IS_EQUAL(endDateWithHist[0][levelID].ptr[i], missval) ) {
-		endDateWithHist[0][levelID].ptr[i] = ovdateSouth; 
-	      }
-	    }
+      /* start with southern sphere */
+      if ( yvals[i] < 0 )
+      {
+        if ( DBL_IS_EQUAL(startDateWithHist[1][levelID].ptr[i], missval) ) {
+          endDateWithHist[0][levelID].ptr[i] = missval;
+          continue;
         }
+        if ( DBL_IS_EQUAL(endDateWithHist[0][levelID].ptr[i], missval) ) {
+          endDateWithHist[0][levelID].ptr[i] = ovdateSouth;
+        }
+      }
+      else
+      {
+        if ( DBL_IS_EQUAL(startDateWithHist[0][levelID].ptr[i], missval) ) {
+          endDateWithHist[0][levelID].ptr[i] = missval;
+          continue;
+        }
+
+        if ( DBL_IS_EQUAL(endDateWithHist[0][levelID].ptr[i], missval) ) {
+          endDateWithHist[0][levelID].ptr[i] = ovdate;
+        }
+      }
     }
+  }
 }
 
 void computeGsl(int nlevels, int gridsize, double *yvals, double missval,
                 field_t *startDateWithHist[2], field_t *endDateWithHist[2],
-                field_t *gslDuration, field_t *gslFirstDay, 
-                int useCurrentYear) 
+                field_t *gslDuration, field_t *gslFirstDay,
+                int useCurrentYear)
 {
-  int levelID, i; 
-  double firstDay, duration; 
+  int levelID, i;
+  double firstDay, duration;
 
   if ( !useCurrentYear )
     {
@@ -542,16 +542,16 @@ void computeGsl(int nlevels, int gridsize, double *yvals, double missval,
         {
           for ( i = 0; i < gridsize; i++ )
             {
-              /* start with northern sphere */
-              if ( yvals[i] >= 0 )
+              /* start with southern sphere */
+              if ( yvals[i] < 0.0 )
                 {
-                  duration = (double) (date_to_julday(CALENDAR_PROLEPTIC, (int)   endDateWithHist[1][levelID].ptr[i]) - 
+                  duration = (double) (date_to_julday(CALENDAR_PROLEPTIC, (int)   endDateWithHist[0][levelID].ptr[i]) -
                                        date_to_julday(CALENDAR_PROLEPTIC, (int) startDateWithHist[1][levelID].ptr[i]));
                   firstDay = (double) day_of_year((int) startDateWithHist[1][levelID].ptr[i]);
                 }
               else
                 {
-                  duration = (double) (date_to_julday(CALENDAR_PROLEPTIC, (int)   endDateWithHist[0][levelID].ptr[i]) - 
+                  duration = (double) (date_to_julday(CALENDAR_PROLEPTIC, (int)   endDateWithHist[1][levelID].ptr[i]) -
                                        date_to_julday(CALENDAR_PROLEPTIC, (int) startDateWithHist[1][levelID].ptr[i]));
                   firstDay = (double) day_of_year((int) startDateWithHist[1][levelID].ptr[i]);
                 }
@@ -567,20 +567,21 @@ void computeGsl(int nlevels, int gridsize, double *yvals, double missval,
         {
           for ( i = 0; i < gridsize; i++ )
             {
-              if ( yvals[i] >= 0 )
+              /* start with southern sphere */
+              if ( yvals[i] < 0.0 )
                 {
-                  duration = (double) (date_to_julday(CALENDAR_PROLEPTIC, (int)   endDateWithHist[0][levelID].ptr[i]) - 
+                  gslDuration[levelID].ptr[i] = missval;
+                  gslFirstDay[levelID].ptr[i] = missval;
+                }
+              else
+                {
+                  duration = (double) (date_to_julday(CALENDAR_PROLEPTIC, (int)   endDateWithHist[0][levelID].ptr[i]) -
                                        date_to_julday(CALENDAR_PROLEPTIC, (int) startDateWithHist[0][levelID].ptr[i]));
                   firstDay = (double) day_of_year((int) startDateWithHist[0][levelID].ptr[i]);
 
                   gslDuration[levelID].ptr[i] = duration;
                   gslFirstDay[levelID].ptr[i] = firstDay;
                 }
-              else
-                {
-                  gslDuration[levelID].ptr[i] = missval;
-                  gslFirstDay[levelID].ptr[i] = missval;
-                }
             }
         }
     }
@@ -600,7 +601,7 @@ void computeGsl(int nlevels, int gridsize, double *yvals, double missval,
     }
 }
 
-void writeGslStream(int ostreamID, int otaxisID, int otsID, 
+void writeGslStream(int ostreamID, int otaxisID, int otsID,
                     int ovarID1, int ovarID2, int ivlistID1,
                     int first_var_id,
                     field_t *gslDuration, field_t *gslFirstDay,
@@ -610,19 +611,16 @@ void writeGslStream(int ostreamID, int otaxisID, int otsID,
 
   taxisDefVdate(otaxisID, vdate);
   taxisDefVtime(otaxisID, vtime);
-  streamDefTimestep(ostreamID, otsID++);
+  streamDefTimestep(ostreamID, otsID);
 
-  if ( otsID == 1 || vlistInqVarTime(ivlistID1, first_var_id) == TIME_VARIABLE )
+  for ( levelID = 0; levelID < nlevels; levelID++ )
     {
-      for ( levelID = 0; levelID < nlevels; levelID++ )
-        {
-          streamDefRecord(ostreamID, ovarID1, levelID);
-          streamWriteRecord(ostreamID, gslDuration[levelID].ptr, gslDuration[levelID].nmiss);
-        }
-      for ( levelID = 0; levelID < nlevels; levelID++ )
-        {
-          streamDefRecord(  ostreamID, ovarID2, levelID);
-          streamWriteRecord(ostreamID, gslFirstDay[levelID].ptr, gslFirstDay[levelID].nmiss);
-        }
+      streamDefRecord(ostreamID, ovarID1, levelID);
+      streamWriteRecord(ostreamID, gslDuration[levelID].ptr, gslDuration[levelID].nmiss);
+    }
+  for ( levelID = 0; levelID < nlevels; levelID++ )
+    {
+      streamDefRecord(  ostreamID, ovarID2, levelID);
+      streamWriteRecord(ostreamID, gslFirstDay[levelID].ptr, gslFirstDay[levelID].nmiss);
     }
 }
