@@ -2,9 +2,12 @@
 #include <stdlib.h>
 #include <string.h>
 #include <math.h>
+#include <errno.h>
 
-#include "cdi.h"
+#include <cdi.h>
 #include "cdo.h"
+#include "cdo_int.h"
+#include "field.h"
 #include "expr.h"
 #include "expr_yacc.h"
 
@@ -14,9 +17,9 @@ typedef struct {
   char *name;                      /* function name            */
   double (*func)(double);          /* pointer to function      */
 }
-FUNC;
+func_t;
 
-static FUNC fun_sym_tbl[] =
+static func_t fun_sym_tbl[] =
 {
   /* scalar functions */
   {0, "sqrt",  sqrt},
@@ -46,7 +49,7 @@ static int NumFunc = sizeof(fun_sym_tbl) / sizeof(fun_sym_tbl[0]);
 static
 nodeType *expr_con_con(int oper, nodeType *p1, nodeType *p2)
 {
-  static char func[] = "expr_con_con";
+  static const char *func = "expr_con_con";
   nodeType *p;
 
   p = (nodeType *) malloc(sizeof(nodeType));
@@ -69,16 +72,19 @@ nodeType *expr_con_con(int oper, nodeType *p1, nodeType *p2)
 static
 nodeType *expr_con_var(int oper, nodeType *p1, nodeType *p2)
 {
-  static char func[] = "expr_con_var";
+  static const char *func = "expr_con_var";
   nodeType *p;
-  int ngp, i;
-  int nlev, k;
+  long ngp, i;
+  long nlev;
+  int nmiss;
   int gridID, zaxisID;
-  double missval;
+  double missval1, missval2;
 
-  gridID  = p2->gridID;
-  zaxisID = p2->zaxisID;
-  missval = p2->missval;
+  gridID   = p2->gridID;
+  zaxisID  = p2->zaxisID;
+  nmiss    = p2->nmiss;
+  missval1 = p2->missval;
+  missval2 = p2->missval;
 
   ngp  = gridInqSize(gridID);
   nlev = zaxisInqSize(zaxisID);
@@ -90,41 +96,76 @@ nodeType *expr_con_var(int oper, nodeType *p1, nodeType *p2)
   p->u.var.nm = strdupx("tmp");
   p->gridID   = gridID;
   p->zaxisID  = zaxisID;
-  p->missval  = missval;
+  p->missval  = missval1;
 
   p->data = (double *) malloc(ngp*nlev*sizeof(double));
 
   switch ( oper )
     {
     case '+':
-      for ( k = 0; k < nlev; k++ )
-	for ( i = 0; i < ngp; i++ )
-	  p->data[i+k*ngp] = p1->u.con.value + p2->data[i+k*ngp];
+      if ( nmiss > 0 )
+	{
+	  for ( i = 0; i < ngp*nlev; i++ )
+	    p->data[i] = ADD(p1->u.con.value, p2->data[i]);
+	}
+      else
+	{
+	  for ( i = 0; i < ngp*nlev; i++ )
+	    p->data[i] = p1->u.con.value + p2->data[i];
+	}
       break;
     case '-':
-      for ( k = 0; k < nlev; k++ )
-	for ( i = 0; i < ngp; i++ )
-	  p->data[i+k*ngp] = p1->u.con.value - p2->data[i+k*ngp];
+      if ( nmiss > 0 )
+	{
+	  for ( i = 0; i < ngp*nlev; i++ )
+	    p->data[i] = SUB(p1->u.con.value, p2->data[i]);
+	}
+      else
+	{
+	  for ( i = 0; i < ngp*nlev; i++ )
+	    p->data[i] = p1->u.con.value - p2->data[i];
+	}
       break;
     case '*':
-      for ( k = 0; k < nlev; k++ )
-	for ( i = 0; i < ngp; i++ )
-	  p->data[i+k*ngp] = p1->u.con.value * p2->data[i+k*ngp];
+      if ( nmiss > 0 )
+	{
+	  for ( i = 0; i < ngp*nlev; i++ )
+	    p->data[i] = MUL(p1->u.con.value, p2->data[i]);
+	}
+      else
+	{
+	  for ( i = 0; i < ngp*nlev; i++ )
+	    p->data[i] = p1->u.con.value * p2->data[i];
+	}
       break;
     case '/':
-      for ( k = 0; k < nlev; k++ )
-	for ( i = 0; i < ngp; i++ )
-	  p->data[i+k*ngp] = p1->u.con.value / p2->data[i+k*ngp];
+	{
+	  for ( i = 0; i < ngp*nlev; i++ )
+	    p->data[i] = DIV(p1->u.con.value, p2->data[i]);
+	}
       break;
     case '^':
-      for ( k = 0; k < nlev; k++ )
-	for ( i = 0; i < ngp; i++ )
-	  p->data[i+k*ngp] = pow(p1->u.con.value, p2->data[i+k*ngp]);
+      if ( nmiss > 0 )
+	{
+	  for ( i = 0; i < ngp*nlev; i++ )
+	    p->data[i] = POW(p1->u.con.value, p2->data[i]);
+	}
+      else
+	{
+	  for ( i = 0; i < ngp*nlev; i++ )
+	    p->data[i] = pow(p1->u.con.value, p2->data[i]);
+	}
       break;
     default:
       cdoAbort("%s: operator %c unsupported!", func, oper);
     }
 
+  nmiss = 0;
+  for ( i = 0; i < ngp*nlev; i++ )
+    if ( DBL_IS_EQUAL(p->data[i], missval1) ) nmiss++;
+
+  p->nmiss = nmiss;
+
   if ( p2->tmpvar ) free(p2->data);
 
   return (p);
@@ -133,16 +174,19 @@ nodeType *expr_con_var(int oper, nodeType *p1, nodeType *p2)
 static
 nodeType *expr_var_con(int oper, nodeType *p1, nodeType *p2)
 {
-  static char func[] = "expr_var_con";
+  static const char *func = "expr_var_con";
   nodeType *p;
-  int ngp, i;
-  int nlev, k;
+  long ngp, i;
+  long nlev;
+  int nmiss;
   int gridID, zaxisID;
-  double missval;
+  double missval1, missval2;
 
-  gridID  = p1->gridID;
-  zaxisID = p1->zaxisID;
-  missval = p1->missval;
+  gridID   = p1->gridID;
+  zaxisID  = p1->zaxisID;
+  nmiss    = p1->nmiss;
+  missval1 = p1->missval;
+  missval2 = p1->missval;
 
   ngp  = gridInqSize(gridID);
   nlev = zaxisInqSize(zaxisID);
@@ -154,41 +198,82 @@ nodeType *expr_var_con(int oper, nodeType *p1, nodeType *p2)
   p->u.var.nm = strdupx("tmp");
   p->gridID   = gridID;
   p->zaxisID  = zaxisID;
-  p->missval  = missval;
+  p->missval  = missval1;
 
   p->data = (double *) malloc(ngp*nlev*sizeof(double));
 
   switch ( oper )
     {
     case '+':
-      for ( k = 0; k < nlev; k++ )
-	for ( i = 0; i < ngp; i++ )
-	  p->data[i+k*ngp] = p1->data[i+k*ngp] + p2->u.con.value;
+      if ( nmiss > 0 )
+	{
+	  for ( i = 0; i < ngp*nlev; i++ )
+	    p->data[i] = ADD(p1->data[i], p2->u.con.value);
+	}
+      else
+	{
+	  for ( i = 0; i < ngp*nlev; i++ )
+	    p->data[i] = p1->data[i] + p2->u.con.value;
+	}
       break;
     case '-':
-      for ( k = 0; k < nlev; k++ )
-	for ( i = 0; i < ngp; i++ )
-	  p->data[i+k*ngp] = p1->data[i+k*ngp] - p2->u.con.value;
+      if ( nmiss > 0 )
+	{
+	  for ( i = 0; i < ngp*nlev; i++ )
+	    p->data[i] = SUB(p1->data[i], p2->u.con.value);
+	}
+      else
+	{
+	  for ( i = 0; i < ngp*nlev; i++ )
+	    p->data[i] = p1->data[i] - p2->u.con.value;
+	}
       break;
     case '*':
-      for ( k = 0; k < nlev; k++ )
-	for ( i = 0; i < ngp; i++ )
-	  p->data[i+k*ngp] = p1->data[i+k*ngp] * p2->u.con.value;
+      if ( nmiss > 0 )
+	{
+	  for ( i = 0; i < ngp*nlev; i++ )
+	    p->data[i] = MUL(p1->data[i], p2->u.con.value);
+	}
+      else
+	{
+	  for ( i = 0; i < ngp*nlev; i++ )
+	    p->data[i] = p1->data[i] * p2->u.con.value;
+	}
       break;
     case '/':
-      for ( k = 0; k < nlev; k++ )
-	for ( i = 0; i < ngp; i++ )
-	  p->data[i+k*ngp] = p1->data[i+k*ngp] / p2->u.con.value;
+      if ( nmiss > 0 || IS_EQUAL(p2->u.con.value, 0) )
+	{
+	  for ( i = 0; i < ngp*nlev; i++ )
+	    p->data[i] = DIV(p1->data[i], p2->u.con.value);
+	}
+      else
+	{
+	  for ( i = 0; i < ngp*nlev; i++ )
+	    p->data[i] = p1->data[i] / p2->u.con.value;
+	}
       break;
     case '^':
-      for ( k = 0; k < nlev; k++ )
-	for ( i = 0; i < ngp; i++ )
-	  p->data[i+k*ngp] = pow(p1->data[i+k*ngp], p2->u.con.value);
+      if ( nmiss > 0 )
+	{
+	  for ( i = 0; i < ngp*nlev; i++ )
+	    p->data[i] = POW(p1->data[i], p2->u.con.value);
+	}
+      else
+	{
+	  for ( i = 0; i < ngp*nlev; i++ )
+	    p->data[i] = pow(p1->data[i], p2->u.con.value);
+	}
       break;
     default:
       cdoAbort("%s: operator %c unsupported!", func, oper);
     }
 
+  nmiss = 0;
+  for ( i = 0; i < ngp*nlev; i++ )
+    if ( DBL_IS_EQUAL(p->data[i], missval1) ) nmiss++;
+
+  p->nmiss = nmiss;
+
   if ( p1->tmpvar ) free(p1->data);
 
   return (p);
@@ -197,11 +282,18 @@ nodeType *expr_var_con(int oper, nodeType *p1, nodeType *p2)
 static
 nodeType *expr_var_var(int oper, nodeType *p1, nodeType *p2)
 {
-  static char func[] = "expr_var_var";
+  static const char *func = "expr_var_var";
   nodeType *p;
-  int ngp, ngp1, ngp2, i;
-  int nlev, nlev1, nlev2, k;
-  int loff1, loff2;
+  long ngp, ngp1, ngp2, i;
+  long nlev, nlev1, nlev2, k;
+  long loff1, loff2;
+  int nmiss, nmiss1, nmiss2;
+  double missval1, missval2;
+
+  nmiss1   = p1->nmiss;
+  nmiss2   = p2->nmiss;
+  missval1 = p1->missval;
+  missval2 = p2->missval;
 
   ngp1 = gridInqSize(p1->gridID);
   ngp2 = gridInqSize(p2->gridID);
@@ -257,30 +349,76 @@ nodeType *expr_var_var(int oper, nodeType *p1, nodeType *p2)
       switch ( oper )
 	{
 	case '+':
-	  for ( i = 0; i < ngp; i++ )
-	    p->data[i+k*ngp] = p1->data[i+loff1] + p2->data[i+loff2];
+	  if ( nmiss1 > 0 || nmiss2 > 0 )
+	    {
+	      for ( i = 0; i < ngp; i++ )
+		p->data[i+k*ngp] = ADD(p1->data[i+loff1], p2->data[i+loff2]);
+	    }
+	  else
+	    {
+	      for ( i = 0; i < ngp; i++ )
+		p->data[i+k*ngp] = p1->data[i+loff1] + p2->data[i+loff2];
+	    }
 	  break;
 	case '-':
-	  for ( i = 0; i < ngp; i++ )
-	    p->data[i+k*ngp] = p1->data[i+loff1] - p2->data[i+loff2];
+	  if ( nmiss1 > 0 || nmiss2 > 0 )
+	    {
+	      for ( i = 0; i < ngp; i++ )
+		p->data[i+k*ngp] = SUB(p1->data[i+loff1], p2->data[i+loff2]);
+	    }
+	  else
+	    {
+	      for ( i = 0; i < ngp; i++ )
+		p->data[i+k*ngp] = p1->data[i+loff1] - p2->data[i+loff2];
+	    }
 	  break;
 	case '*':
-	  for ( i = 0; i < ngp; i++ )
-	    p->data[i+k*ngp] = p1->data[i+loff1] * p2->data[i+loff2];
+	  if ( nmiss1 > 0 || nmiss2 > 0 )
+	    {
+	      for ( i = 0; i < ngp; i++ )
+		p->data[i+k*ngp] = MUL(p1->data[i+loff1], p2->data[i+loff2]);
+	    }
+	  else
+	    {
+	      for ( i = 0; i < ngp; i++ )
+		p->data[i+k*ngp] = p1->data[i+loff1] * p2->data[i+loff2];
+	    }
 	  break;
 	case '/':
-	  for ( i = 0; i < ngp; i++ )
-	    p->data[i+k*ngp] = p1->data[i+loff1] / p2->data[i+loff2];
+	  if ( nmiss1 > 0 || nmiss2 > 0 )
+	    {
+	      for ( i = 0; i < ngp; i++ )
+		p->data[i+k*ngp] = DIV(p1->data[i+loff1], p2->data[i+loff2]);
+	    }
+	  else
+	    {
+	      for ( i = 0; i < ngp; i++ )
+		p->data[i+k*ngp] = p1->data[i+loff1] / p2->data[i+loff2];
+	    }
 	  break;
 	case '^':
-	  for ( i = 0; i < ngp; i++ )
-	    p->data[i+k*ngp] = pow(p1->data[i+loff1], p2->data[i+loff2]);
+	  if ( nmiss1 > 0 || nmiss2 > 0 )
+	    {
+	      for ( i = 0; i < ngp; i++ )
+		p->data[i+k*ngp] = POW(p1->data[i+loff1], p2->data[i+loff2]);
+	    }
+	  else
+	    {
+	      for ( i = 0; i < ngp; i++ )
+		p->data[i+k*ngp] = pow(p1->data[i+loff1], p2->data[i+loff2]);
+	    }
 	  break;
 	default:
 	  cdoAbort("%s: operator %c unsupported!", func, oper);
 	}
     }
 
+  nmiss = 0;
+  for ( i = 0; i < ngp*nlev; i++ )
+    if ( DBL_IS_EQUAL(p->data[i], missval1) ) nmiss++;
+
+  p->nmiss = nmiss;
+
   if ( p1->tmpvar ) free(p1->data);
   if ( p2->tmpvar ) free(p2->data);
 
@@ -290,8 +428,8 @@ nodeType *expr_var_var(int oper, nodeType *p1, nodeType *p2)
 static
 void ex_copy(nodeType *p2, nodeType *p1)
 {
-  int ngp, ngp1, ngp2, i;
-  int nlev, k;
+  long ngp, ngp1, ngp2, i;
+  long nlev;
 
   if ( cdoVerbose )
     printf("\tcopy %s\n", p1->u.var.nm);
@@ -302,9 +440,11 @@ void ex_copy(nodeType *p2, nodeType *p1)
   ngp = ngp2;
   nlev = zaxisInqSize(p2->zaxisID);
 
-  for ( k = 0; k < nlev; k++ )
-    for ( i = 0; i < ngp; i++ )
-      p2->data[i+k*ngp] = p1->data[i+k*ngp];
+  for ( i = 0; i < ngp*nlev; i++ )
+    p2->data[i] = p1->data[i];
+
+  p2->missval = p1->missval;
+  p2->nmiss   = p1->nmiss;
 }
 
 static
@@ -345,7 +485,7 @@ nodeType *expr(int oper, nodeType *p1, nodeType *p2)
 static
 nodeType *ex_fun_con(char *fun, nodeType *p1)
 {
-  static char func[] = "ex_fun_con";
+  static const char *func = "ex_fun_con";
   nodeType *p;
   int i;
   int funcID = -1;
@@ -373,16 +513,18 @@ nodeType *ex_fun_con(char *fun, nodeType *p1)
 static
 nodeType *ex_fun_var(char *fun, nodeType *p1)
 {
-  static char func[] = "ex_fun_var";
+  static const char *func = "ex_fun_var";
   nodeType *p;
-  int ngp, i;
-  int nlev, k;
+  long ngp, i;
+  long nlev;
   int gridID, zaxisID;
   int funcID = -1;
+  int nmiss;
   double missval;
 
   gridID  = p1->gridID;
   zaxisID = p1->zaxisID;
+  nmiss   = p1->nmiss;
   missval = p1->missval;
 
   ngp  = gridInqSize(gridID);
@@ -409,19 +551,31 @@ nodeType *ex_fun_var(char *fun, nodeType *p1)
   if ( funcID == -1 )
     cdoAbort("function %s not available!", fun);
 
-  if ( strcmp("log", fun) == 0 )
+  if ( nmiss > 0 )
     {
-      for ( k = 0; k < nlev; k++ )
-	for ( i = 0; i < ngp; i++ )
-	  p->data[i+k*ngp] = log(p1->data[i+k*ngp]);
+      for ( i = 0; i < ngp*nlev; i++ )
+	{
+	  errno = -1;
+	  p->data[i] = DBL_IS_EQUAL(p1->data[i], missval) ? missval : fun_sym_tbl[funcID].func(p1->data[i]);
+	  if ( errno == EDOM || errno == ERANGE ) p->data[i] = missval;
+	}
     }
   else
     {
-      for ( k = 0; k < nlev; k++ )
-	for ( i = 0; i < ngp; i++ )
-	  p->data[i+k*ngp] = fun_sym_tbl[funcID].func(p1->data[i+k*ngp]);
+      for ( i = 0; i < ngp*nlev; i++ )
+	{
+	  errno = -1;
+	  p->data[i] = fun_sym_tbl[funcID].func(p1->data[i]);
+	  if ( errno == EDOM || errno == ERANGE ) p->data[i] = missval;
+	}
     }
 
+  nmiss = 0;
+  for ( i = 0; i < ngp*nlev; i++ )
+    if ( DBL_IS_EQUAL(p->data[i], missval) ) nmiss++;
+
+  p->nmiss = nmiss;
+
   if ( p1->tmpvar ) free(p1->data);
 
   return (p);
@@ -451,16 +605,18 @@ nodeType *ex_fun(char *fun, nodeType *p1)
 static
 nodeType *ex_uminus_var(nodeType *p1)
 {
-  static char func[] = "ex_uminus_var";
+  static const char *func = "ex_uminus_var";
   nodeType *p;
-  int ngp, i;
-  int nlev, k;
+  long ngp, i;
+  long nlev;
+  int nmiss;
   int gridID, zaxisID;
   double missval;
 
-  gridID  = p1->gridID;
-  zaxisID = p1->zaxisID;
-  missval = p1->missval;
+  gridID   = p1->gridID;
+  zaxisID  = p1->zaxisID;
+  nmiss    = p1->nmiss;
+  missval  = p1->missval;
 
   ngp  = gridInqSize(gridID);
   nlev = zaxisInqSize(zaxisID);
@@ -476,17 +632,26 @@ nodeType *ex_uminus_var(nodeType *p1)
 
   p->data = (double *) malloc(ngp*nlev*sizeof(double));
 
-  for ( k = 0; k < nlev; k++ )
-    for ( i = 0; i < ngp; i++ )
-      p->data[i+k*ngp] = -(p1->data[i+k*ngp]);
+  if ( nmiss > 0 )
+    {
+      for ( i = 0; i < ngp*nlev; i++ )
+	p->data[i] = DBL_IS_EQUAL(p1->data[i], missval) ? missval : -(p1->data[i]);
+    }
+  else
+    {
+      for ( i = 0; i < ngp*nlev; i++ )
+	p->data[i] = -(p1->data[i]);
+    }
 
+  p->nmiss = nmiss;
+  
   return (p);
 }
 
 static
 nodeType *ex_uminus_con(nodeType *p1)
 {
-  static char func[] = "ex_uminus_con";
+  static const char *func = "ex_uminus_con";
   nodeType *p;
 
   p = (nodeType *) malloc(sizeof(nodeType));
@@ -544,7 +709,7 @@ int exNode(nodeType *p, parse_parm_t *parse_arg)
 
 nodeType *ex(nodeType *p, parse_parm_t *parse_arg)
 {
-  static char func[] = "ex";
+  static const char *func = "ex";
   int gridID1 = -1, zaxisID1 = -1, timeID1 = -1;
   double missval = 0;
   char varname[256];
@@ -584,7 +749,7 @@ nodeType *ex(nodeType *p, parse_parm_t *parse_arg)
 
 	  if ( varID == nvars )
 	    {
-	      cdoAbort("variable >%s< not found!", p->u.var.nm);
+	      cdoAbort("Variable >%s< not found!", p->u.var.nm);
 	    }
 	  else
 	    {
@@ -620,7 +785,10 @@ nodeType *ex(nodeType *p, parse_parm_t *parse_arg)
 	  p->missval = missval;
           p->nmiss   = 0;
 	  if ( ! parse_arg->init )
-	    p->data    = parse_arg->vardata1[varID];
+	    {
+	      p->data  = parse_arg->vardata1[varID];
+	      p->nmiss = parse_arg->nmiss[varID];
+	    }
 	  p->tmpvar  = 0;
 	  rnode = p;
 	}
@@ -689,8 +857,8 @@ nodeType *ex(nodeType *p, parse_parm_t *parse_arg)
 		  p->gridID  = parse_arg->gridID2;
 		  p->zaxisID = parse_arg->zaxisID2;
 		  p->missval = missval;
-		  p->data = parse_arg->vardata2[varID];
-		  p->tmpvar = 0;
+		  p->data    = parse_arg->vardata2[varID];
+		  p->tmpvar  = 0;
 
 		  ex_copy(p, rnode);
 
