@@ -17,7 +17,7 @@
 
 #include "cdo.h"
 #include "cdo_int.h"
-#include "cdi.h"
+#include <cdi.h>
 /* RQ */
 #include "nth_element.h"
 /* QR */
@@ -42,9 +42,14 @@ double _FDIV_(double x, double y, double missval1, double missval2)
   return FDIV(x, y);
 }
 
-double _FROOT_(double x, double missval1)
+double _FPOW_(double x, double y, double missval1, double missval2)
 {
-  return FROOT(x);
+  return FPOW(x, y);
+}
+
+double _FSQRT_(double x, double missval1)
+{
+  return FSQRT(x);
 }
 
 
@@ -53,11 +58,11 @@ double fldfun(field_t field, int function)
   double rval = 0;
 
   if      ( function == func_min  )  rval = fldmin(field);
-  else if ( function == func_max  )  rval = fldmax(field);  
-  else if ( function == func_sum  )  rval = fldsum(field);  
-  else if ( function == func_mean )  rval = fldmean(field);  
-  else if ( function == func_avg  )  rval = fldavg(field);  
-  else if ( function == func_std  )  rval = fldstd(field);  
+  else if ( function == func_max  )  rval = fldmax(field);
+  else if ( function == func_sum  )  rval = fldsum(field);
+  else if ( function == func_mean )  rval = fldmean(field);
+  else if ( function == func_avg  )  rval = fldavg(field);
+  else if ( function == func_std  )  rval = fldstd(field);
   else if ( function == func_var  )  rval = fldvar(field);
   else cdoAbort("function %d not implemented!", function);
 
@@ -327,7 +332,7 @@ void fldrms(field_t field, field_t field2, field_t *field3)
     }
     */
 
-  ravg = ROOT(DIV(rsum, rsumw));
+  ravg = SQRT(DIV(rsum, rsumw));
 
   if ( DBL_IS_EQUAL(ravg, missval1) ) rnmiss++;
 
@@ -381,7 +386,7 @@ void varrms(field_t field, field_t field2, field_t *field3)
     }
     */
 
-  ravg = ROOT(DIV(rsum, rsumw));
+  ravg = SQRT(DIV(rsum, rsumw));
 
   if ( DBL_IS_EQUAL(ravg, missval1) ) rnmiss++;
 
@@ -392,30 +397,30 @@ void varrms(field_t field, field_t field2, field_t *field3)
 /* RQ */
 double fldpctl(field_t field, int p)
 {
-  static const char func[] = "fldpctl";
-  
+  static const char *func = "fldpctl";
+
   long   len     = field.size;
   int    nmiss   = field.nmiss;
   double missval = field.missval;
   double *array  = field.ptr;
   double *array2;
-	
+
   long i, j;
   double pctl = missval;
-  
+
   if ( len - nmiss > 0 )
     {
       if ( nmiss > 0 )
         {
           array2 = (double *) malloc((len - nmiss)*sizeof(double));
-          
+
           for ( i = 0, j = 0; i < len; i++ ) 
             if ( !DBL_IS_EQUAL(array[i], missval) )
               array2[j++] = array[i];
 
           pctl = nth_element(array2, j, (int)ceil(j*(p/100.0))-1);
-          
-          free(array2);	  
+
+          free(array2);
         }
       else
         {
@@ -426,3 +431,29 @@ double fldpctl(field_t field, int p)
   return pctl;
 }
 /* QR */
+
+/*  field_t UTILITIES */
+/*  update the number non missing values */
+void fldunm(field_t *field)
+{
+  long i;
+
+  field->nmiss = 0;
+  for ( i = 0; i < field->size; i++ )
+    if ( DBL_IS_EQUAL(field->ptr[i], field->missval) ) field->nmiss++;
+}
+
+/*  check for non missval values */
+int fldhvs(field_t *fieldPtr, int nlevels)
+{
+  int level;
+  field_t field;
+
+  for ( level = 0; level < nlevels; level++)
+    {
+      field = fieldPtr[level];
+      if ( field.nmiss != field.size )
+        return TRUE;
+    }
+  return FALSE;
+}
