@@ -28,21 +28,24 @@
 #define  FSUB(x,y)  (DBL_IS_EQUAL((x),missval1) || DBL_IS_EQUAL((y),missval2) ? missval1 : (x)-(y))
 #define  FMUL(x,y)  (DBL_IS_EQUAL((x),0.)||IS_EQUAL((y),0.) ? 0 : DBL_IS_EQUAL((x),missval1) || DBL_IS_EQUAL((y),missval2) ? missval1 : (x)*(y))
 #define  FDIV(x,y)  (DBL_IS_EQUAL((x),missval1) || DBL_IS_EQUAL((y),missval2) || DBL_IS_EQUAL((y),0.) ? missval1 : (x)/(y))
-#define  FROOT(x)   (DBL_IS_EQUAL((x),missval1) || (x)<0 ? missval1 : sqrt(x))
+#define  FPOW(x,y)  (DBL_IS_EQUAL((x),missval1) || DBL_IS_EQUAL((y),missval2) ? missval1 : pow((x),(y)))
+#define  FSQRT(x)   (DBL_IS_EQUAL((x),missval1) || (x)<0 ? missval1 : sqrt(x))
 
 
 double _FADD_(double x, double y, double missval1, double missval2);
 double _FSUB_(double x, double y, double missval1, double missval2);
 double _FMUL_(double x, double y, double missval1, double missval2);
 double _FDIV_(double x, double y, double missval1, double missval2);
-double _FROOT_(double x, double missval1);
+double _FPOW_(double x, double y, double missval1, double missval2);
+double _FSQRT_(double x, double missval1);
 
 
 #define ADD(x,y)  _FADD_(x, y, missval1, missval2)
 #define SUB(x,y)  _FSUB_(x, y, missval1, missval2)
 #define MUL(x,y)  _FMUL_(x, y, missval1, missval2)
 #define DIV(x,y)  _FDIV_(x, y, missval1, missval2)
-#define ROOT(x)   _FROOT_(x, missval1)
+#define POW(x,y)  _FPOW_(x, y, missval1, missval2)
+#define SQRT(x)   _FSQRT_(x, missval1)
 
 
 typedef struct {
@@ -76,6 +79,8 @@ double fldvar(field_t field);
 /* RQ */
 double fldpctl(field_t field, int k);
 /* QR */
+void   fldunm(field_t *field);
+int    fldhvs(field_t *field, int nlevels);
 
 /* fieldzon.c */
 
