@@ -17,7 +17,7 @@
 
 #include "cdo.h"
 #include "cdo_int.h"
-#include "cdi.h"
+#include <cdi.h>
 /* RQ */
 #include "nth_element.h"
 /* QR */
@@ -355,7 +355,7 @@ void merstd(field_t field1, field_t *field2)
 /* RQ */
 void merpctl(field_t field1, field_t *field2, int p)
 {
-  static const char func[] = "merpctl";
+  static const char *func = "merpctl";
 
   long   i, j, l, nx, ny;
   int    rnmiss = 0;
