@@ -17,7 +17,7 @@
 
 #include "cdo.h"
 #include "cdo_int.h"
-#include "cdi.h"
+#include <cdi.h>
 /* RQ */
 #include "nth_element.h"
 /* QR */
@@ -350,7 +350,7 @@ void zonstd(field_t field1, field_t *field2)
 /* RQ */
 void zonpctl(field_t field1, field_t *field2, int p)
 {
-  static const char func[] = "zonpctl";
+  static const char *func = "zonpctl";
 
   long   i, j, l, nx, ny;
   int    rnmiss = 0;
