@@ -2,6 +2,7 @@
 #define _FUNCTS_H
 
 #define  func_all    8
+#define  func_hrd    9
 
 #define  func_min   10
 #define  func_max   11
@@ -16,12 +17,6 @@
 
 #define  func_fld   21
 
-#define  func_hrd   31
-#define  func_sft   32
-#define  func_sftn  33
-#define  func_sftc  34
-#define  func_code  35
-
 #define  func_add   41
 #define  func_sub   42
 #define  func_mul   43
@@ -42,4 +37,16 @@
 #define  func_lon   98
 #define  func_lat   99
 
+enum cmp_flag {
+  CMP_CODE     = 1,
+  CMP_NAME     = 2,
+  CMP_GRID     = 4,
+  CMP_NLEVEL   = 8,
+  CMP_GRIDSIZE = 16,
+  CMP_HRD      = CMP_CODE | CMP_GRIDSIZE,
+  CMP_SFT      = CMP_GRIDSIZE | CMP_NLEVEL | CMP_GRID,
+};
+
+void    vlistCompare(int vlistID1, int vlistID2, int flag);
+
 #endif  /* _FUNCTS_H */
