@@ -4,7 +4,7 @@
 #include <ctype.h>
 #include <math.h>
 
-#include "cdi.h"
+#include <cdi.h>
 /* #include "cdo.h" */
 /* #include "cdo_int.h" */
 #include "gradsdeslib.h"
