@@ -29,7 +29,7 @@
 #include <ctype.h>
 #include <math.h>
 
-#include "cdi.h"
+#include <cdi.h>
 #include "cdo.h"
 #include "cdo_int.h"
 #include "grid.h"
@@ -58,6 +58,7 @@ void extClose(int fileID);
 
 void gridInit(grid_t *grid)
 {
+  grid->mask          = NULL;
   grid->xvals         = NULL;
   grid->yvals         = NULL;
   grid->xbounds       = NULL;
@@ -162,7 +163,7 @@ int getoptname(char *optname, const char *optstring, int nopt)
 
 int gridDefine(grid_t grid)
 {
-  static char func[] = "gridDefine";
+  static const char *func = "gridDefine";
   int gridID = UNDEFID;
   int i;
 
@@ -270,6 +271,13 @@ int gridDefine(grid_t grid)
 	    gridDefXpole(gridID, grid.xpole);
 	    gridDefYpole(gridID, grid.ypole);
 	  }
+
+	if ( grid.mask )
+	  {
+	    gridDefMask(gridID, grid.mask);
+	    free(grid.mask);
+	  }
+
 	break;
       }
     case GRID_CURVILINEAR:
@@ -323,6 +331,12 @@ int gridDefine(grid_t grid)
 	    free(grid.ybounds);
 	  }
 
+	if ( grid.mask )
+	  {
+	    gridDefMask(gridID, grid.mask);
+	    free(grid.mask);
+	  }
+
 	break;
       }
     case GRID_LCC:
@@ -350,6 +364,12 @@ int gridDefine(grid_t grid)
 	gridDefLCC(gridID, grid.originLon, grid.originLat, grid.lonParY,
 		   grid.lat1, grid.lat2, grid.xinc, grid.yinc, grid.projflag, grid.scanflag);
 
+	if ( grid.mask )
+	  {
+	    gridDefMask(gridID, grid.mask);
+	    free(grid.mask);
+	  }
+
 	break;
       }
     case GRID_LCC2:
@@ -399,6 +419,12 @@ int gridDefine(grid_t grid)
 
 	gridDefLcc2(gridID, grid.a, grid.lon_0, grid.lat_0, grid.lat_1, grid.lat_2);
 
+	if ( grid.mask )
+	  {
+	    gridDefMask(gridID, grid.mask);
+	    free(grid.mask);
+	  }
+
 	break;
       }
     case GRID_SPECTRAL:
@@ -415,13 +441,13 @@ int gridDefine(grid_t grid)
 	gridDefTrunc(gridID, grid.ntr);
 
 	gridDefComplexPacking(gridID, grid.lcomplex);
-	
+
 	break;
       }
     case GRID_GME:
       {
-	if ( grid.nd == 0 ) Error(func, "nd undefined!");
-	if ( grid.ni == 0 ) Error(func, "ni undefined!");
+	if ( grid.nd   == 0 ) Error(func, "nd undefined!");
+	if ( grid.ni   == 0 ) Error(func, "ni undefined!");
 	if ( grid.size == 0 ) Error(func, "size undefined!");
 
 	gridID = gridCreate(grid.type, grid.size);
@@ -433,6 +459,12 @@ int gridDefine(grid_t grid)
 	gridDefGMEni2(gridID, grid.ni2);
 	gridDefGMEni3(gridID, grid.ni3);
 	
+	if ( grid.mask )
+	  {
+	    gridDefMask(gridID, grid.mask);
+	    free(grid.mask);
+	  }
+
 	break;
       }
     default:
@@ -454,7 +486,8 @@ int gridDefine(grid_t grid)
   return (gridID);
 }
 
-static char *skipSeparator(char *pline)
+static
+char *skipSeparator(char *pline)
 {
   while ( isspace((int) *pline) ) pline++;
   if ( *pline == '=' || *pline == ':' ) pline++;
@@ -463,6 +496,7 @@ static char *skipSeparator(char *pline)
   return (pline);
 }
 
+
 void fnmexp2(char *out, char *in1, const char *in2)
 {
   const char *pos, *ch;
@@ -522,7 +556,7 @@ void fnmexp2(char *out, char *in1, const char *in2)
 /*
 double *readfield(grid_t *grid, int record, char *format, char *filename)
 {
-  static char func[] = "readfield";
+  static const char *func = "readfield";
   int fileID, rxysize, ierr, irec;
   double *vals;
 
@@ -558,7 +592,7 @@ double *readfield(grid_t *grid, int record, char *format, char *filename)
 /*
 double *readfield4(grid_t *grid, int record, char *format, char *filename)
 {
-  static char func[] = "readfield4";
+  static const char *func = "readfield4";
   int fileID, rxysize, ierr, irec;
   double *vals;
 
@@ -609,7 +643,7 @@ double readflt(const char *name, const char *pline)
 
 int gridFromFile(FILE *gfp, const char *dname)
 {
-  static char func[] = "gridFromFile";
+  static const char *func = "gridFromFile";
   char line[MAX_LINE_LEN], *pline;
   int gridID = -1;
   int size;
@@ -893,6 +927,48 @@ int gridFromFile(FILE *gfp, const char *dname)
 	      grid.xvals[i] = flon;
 	    }
 	}
+      else if ( cmpstr(pline, "mask", len)  == 0 )
+	{
+	  int i = 0;
+	  long lval;
+	  char *endptr;
+
+	  size = grid.size;
+
+	  if ( size > 0 )
+	    {
+	      long count = 0;
+	      pline = skipSeparator(pline + len);
+	      grid.mask = (int *) malloc(size*sizeof(int));
+
+	      for ( i = 0; i < size; i++ )
+		{
+		  endptr = pline;
+		  lval = strtol(pline, &endptr, 10);
+		  if ( pline == endptr )
+		    {
+		      if ( ! readline(gfp, line, MAX_LINE_LEN) )
+			{
+			  Warning(func, "Incomplete command: >mask<");
+			  break;
+			}
+		      pline = line;
+		      lval = strtol(pline, &endptr, 10);
+		    }
+		  grid.mask[i] = (int)lval;
+		  if ( grid.mask[i] == 1 ) count++;
+		  pline = endptr;
+		}
+
+	      if ( count == size )
+		{
+		  free(grid.mask);
+		  grid.mask = NULL;
+		}
+	    }
+	  else
+	    Warning(func, "gridsize undefined!");
+	}
       else if ( cmpstr(pline, "xvals", len)  == 0 )
 	{
 	  int i = 0;
@@ -1137,7 +1213,7 @@ int input_darray(FILE *gfp, int n_values, double *array)
 
 int gridFromPingo(FILE *gfp, const char *dname)
 {
-  static char func[] = "gridFromPingo";
+  static const char *func = "gridFromPingo";
   int gridID = -1;
   int i;
   int nlon, nlat;
@@ -1272,7 +1348,7 @@ int nlat2ntr_linear(int nlat)
 
 int ntr2nlat(int ntr)
 {
-  static char func[] = "ntr2nlat";
+  static const char *func = "ntr2nlat";
   int nlat, nlat2;
 
   nlat = NINT((ntr*3.+1.)/2.);
@@ -1292,7 +1368,7 @@ int ntr2nlat(int ntr)
 
 int ntr2nlat_linear(int ntr)
 {
-  static char func[] = "ntr2nlat_linear";
+  static const char *func = "ntr2nlat_linear";
   int nlat, nlat2;
 
   nlat = NINT((ntr*2.+1.)/2.);
@@ -1345,7 +1421,7 @@ int compNlon(int nlat)
 
 void gen_grid_lonlat(grid_t *grid, const char *pline, double inc, double lon1, double lon2, double lat1, double lat2)
 {
-  static char func[] = "gen_grid_lonlat";
+  static const char *func = "gen_grid_lonlat";
   int nlon, nlat, i;
 
   grid->type = GRID_LONLAT;
@@ -1373,7 +1449,7 @@ void gen_grid_lonlat(grid_t *grid, const char *pline, double inc, double lon1, d
 
 int gridFromName(const char *gridname)
 {
-  static char func[] = "gridFromName";
+  static const char *func = "gridFromName";
   const char *pline;
   int gridID = UNDEFID;
   grid_t grid;
@@ -1391,15 +1467,16 @@ int gridFromName(const char *gridname)
 	  if      ( cmpstr(pline, "grid", len) == 0 ) grid.type = GRID_GAUSSIAN;
 	  else if ( cmpstr(pline, "zon",  len) == 0 ) grid.type = GRID_GAUSSIAN;
 	  else if ( cmpstr(pline, "spec", len) == 0 ) grid.type = GRID_SPECTRAL;
+	  else                                        grid.type = GRID_SPECTRAL;
       
-	  grid.ysize = ntr2nlat_linear(grid.ntr);
-	  if ( cmpstr(pline, "zon",  len) == 0 )
-	    grid.xsize = 1;
-	  else
-	    grid.xsize = compNlon(grid.ysize);
-
 	  if ( grid.type == GRID_GAUSSIAN )
 	    {
+	      grid.ysize = ntr2nlat_linear(grid.ntr);
+	      if ( cmpstr(pline, "zon",  len) == 0 )
+		grid.xsize = 1;
+	      else
+		grid.xsize = compNlon(grid.ysize);
+
 	      grid.def_xfirst = TRUE;
 	      grid.def_yfirst = TRUE;	      
 	    }
@@ -1415,15 +1492,16 @@ int gridFromName(const char *gridname)
 	  if      ( cmpstr(pline, "grid", len) == 0 ) grid.type = GRID_GAUSSIAN;
 	  else if ( cmpstr(pline, "zon",  len) == 0 ) grid.type = GRID_GAUSSIAN;
 	  else if ( cmpstr(pline, "spec", len) == 0 ) grid.type = GRID_SPECTRAL;
+	  else                                        grid.type = GRID_SPECTRAL;
       
-	  grid.ysize = ntr2nlat(grid.ntr);
-	  if ( cmpstr(pline, "zon",  len) == 0 )
-	    grid.xsize = 1;
-	  else
-	    grid.xsize = compNlon(grid.ysize);
-
 	  if ( grid.type == GRID_GAUSSIAN )
 	    {
+	      grid.ysize = ntr2nlat(grid.ntr);
+	      if ( cmpstr(pline, "zon",  len) == 0 )
+		grid.xsize = 1;
+	      else
+		grid.xsize = compNlon(grid.ysize);
+
 	      grid.def_xfirst = TRUE;
 	      grid.def_yfirst = TRUE;	      
 	    }
@@ -1493,6 +1571,27 @@ int gridFromName(const char *gridname)
 	  grid.size = (grid.ni+1)*(grid.ni+1)*10;
 	}
     }
+  else if ( gridname[0] == 'n' ) /* n<N> */
+    {
+      pline = &gridname[1];
+      if ( isdigit((int) *pline) )
+	{
+	  int n;
+	  n = atoi(pline);
+	  while ( isdigit((int) *pline) ) pline++;
+
+	  grid.type = GRID_GAUSSIAN;
+	  grid.ysize = n*2;
+
+	  if ( cmpstr(pline, "zon",  len) == 0 )
+	    grid.xsize = 1;
+	  else
+	    grid.xsize = compNlon(grid.ysize);
+
+	  grid.def_xfirst = TRUE;
+	  grid.def_yfirst = TRUE;	      
+	}
+    }
   else if ( gridname[0] == 'g' && isdigit(gridname[1])) /* g<LON>x<LAT> or g<SIZE> */
     {
       pline = &gridname[1];
@@ -1553,7 +1652,7 @@ int gridFromName(const char *gridname)
 
 int cdoDefineGrid(const char *gridfile)
 {
-  static char func[] = "cdoDefineGrid";
+  static const char *func = "cdoDefineGrid";
   FILE *gfp;
   char buffer[4];
   int gridID = -1;
