@@ -8,7 +8,7 @@
 
 #include <stdio.h>
 
-#include "cdi.h"
+#include <cdi.h>
 #include "cdo.h"
 #include "cdo_int.h"
 #include "griddes.h"
@@ -45,7 +45,7 @@ int cdf_openread(const char *filename)
 
 int gridFromNCfile(const char *gridfile)
 {
-  static char func[] = "gridFromNCfile";
+  static const char *func = "gridFromNCfile";
   int gridID = -1;
 #if  defined  (HAVE_LIBNETCDF)
   int nc_file_id;      /* netCDF grid file id           */
@@ -57,6 +57,7 @@ int gridFromNCfile(const char *gridfile)
   int nc_gridclon_id;  /* netCDF grid corner lon var id */
   int nc_gridlat_id;   /* netCDF grid center lat var id */
   int nc_gridlon_id;   /* netCDF grid center lon var id */
+  int nc_gridmask_id;  /* netCDF grid mask id           */
 
   nc_type xtype;
   size_t attlen;
@@ -86,12 +87,12 @@ int gridFromNCfile(const char *gridfile)
 	   nc_inq_varid(nc_file_id, "grid_corner_lat", &nc_gridclat_id) != NC_NOERR || 
 	   nc_inq_varid(nc_file_id, "grid_corner_lon", &nc_gridclon_id) != NC_NOERR ) return (gridID);
 
-      nce(nc_inq_varid(nc_file_id, "grid_dims", &nc_griddims_id));
       nce(nc_get_var_int(nc_file_id, nc_griddims_id, grid_dims));
 
       if ( grid_rank == 1 )
 	{
 	  grid.type = GRID_CELL;
+	  if ( (size_t)grid_dims[0] != grid_size ) return(gridID);
 	}
       else
 	{
@@ -101,6 +102,7 @@ int gridFromNCfile(const char *gridfile)
 
 	  grid.xsize = grid_dims[0];
 	  grid.ysize = grid_dims[1];
+	  if ( (size_t)grid_dims[0]*grid_dims[1] != grid_size ) return(gridID);
 	}
 
       /* allocate grid coordinates and read data */
@@ -110,11 +112,6 @@ int gridFromNCfile(const char *gridfile)
       grid.xbounds = (double *) malloc(grid.nvertex*grid.size*sizeof(double));
       grid.ybounds = (double *) malloc(grid.nvertex*grid.size*sizeof(double));
 
-      nce(nc_inq_varid(nc_file_id, "grid_center_lat", &nc_gridlat_id));
-      nce(nc_inq_varid(nc_file_id, "grid_center_lon", &nc_gridlon_id));
-      nce(nc_inq_varid(nc_file_id, "grid_corner_lat", &nc_gridclat_id));
-      nce(nc_inq_varid(nc_file_id, "grid_corner_lon", &nc_gridclon_id));
-
       nce(nc_inq_vartype(nc_file_id, nc_gridlat_id, &xtype));
       if ( xtype == NC_FLOAT )  grid.prec = DATATYPE_FLT32;
       else                      grid.prec = DATATYPE_FLT64;
@@ -131,6 +128,21 @@ int gridFromNCfile(const char *gridfile)
       nce(nc_get_att_text(nc_file_id, nc_gridlat_id, "units", grid.yunits));
       grid.yunits[attlen] = 0;
 
+      if ( nc_inq_varid(nc_file_id, "grid_imask", &nc_gridmask_id) == NC_NOERR )
+	{
+	  int i;
+	  grid.mask = (int *) malloc(grid.size*sizeof(int));
+	  nce(nc_get_var_int(nc_file_id, nc_gridmask_id, grid.mask));
+	  for ( i = 0; i < grid.size; ++i )
+	    if ( grid.mask[i] != 1 ) break;
+
+	  if ( i == grid.size )
+	    {
+	      free(grid.mask);
+	      grid.mask = NULL;
+	    }
+	}
+
       gridID = gridDefine(grid);
     }
 
@@ -146,7 +158,7 @@ int gridFromNCfile(const char *gridfile)
 
 void writeNCgrid(const char *gridfile, int gridID, int *grid_imask)
 {
-  static char func[] = "writeNCgrid";
+  static const char *func = "writeNCgrid";
 #if  defined  (HAVE_LIBNETCDF)
   int nc_file_id;      /* netCDF grid file id           */
   int nc_gridsize_id;  /* netCDF grid size dim id       */
