@@ -20,7 +20,7 @@
 #include <string.h>
 #include <ctype.h>
 
-#include "cdi.h"
+#include <cdi.h>
 #include "cdo.h"
 #include "cdo_int.h"
 #include "error.h"
@@ -33,7 +33,7 @@ int cdoDefaultInstID = UNDEFID;
 
 int readInstitution(const char *instfile)
 {
-  static char func[] = "readInstitution";
+  static const char *func = "readInstitution";
   int instID = UNDEFID;
   char line[1024], *pline;
   int lnr = 0;
@@ -99,7 +99,7 @@ int readInstitution(const char *instfile)
 
 void defineInstitution(char *instarg)
 {
-  static char func[] = "defineInstitution";
+  static const char *func = "defineInstitution";
   char *instname;
   int instID;
 
