@@ -18,7 +18,7 @@
 #include <stdio.h>
 #include <string.h>
 #include <stdlib.h>
-#include "cdi.h"
+#include <cdi.h>
 #include "cdo.h"
 #include "operator_help.h"
 #include "modules.h"
@@ -80,6 +80,7 @@ void *Gridboxstat(void *argument);
 void *Gridcell(void *argument);
 void *Harmonic(void *argument);
 void *Histogram(void *argument);
+void *IFS2ICON(void *argument);
 void *Importamsr(void *argument);
 void *Importbinary(void *argument);
 void *Importcmsaf(void *argument);
@@ -182,6 +183,7 @@ void *Wind(void *argument);
 void *Writegrid(void *argument);
 void *Writerandom(void *argument);
 void *Yhourstat(void *argument);
+void *Ydayarith(void *argument);
 void *Ydaypctl(void *argument);
 void *Ydaystat(void *argument);
 void *Ydrunpctl(void *argument);
@@ -281,9 +283,10 @@ void *Wct(void *argument);
 #define  GradsdesOperators      {"gradsdes1", "gradsdes2", "dumpmap"}
 #define  GridboxstatOperators   {"gridboxmin", "gridboxmax", "gridboxsum", "gridboxmean", "gridboxavg", \
                                  "gridboxvar", "gridboxstd"}
-#define  GridcellOperators      {"gridarea", "gridweights"}
+#define  GridcellOperators      {"gridarea", "gridweights", "gridmask"}
 #define  HarmonicOperators      {"harmonic"}
 #define  HistogramOperators     {"histcount", "histsum", "histmean", "histfreq"}
+#define  IFS2ICONOperators      {"ifs2icon"}
 #define  ImportamsrOperators    {"import_amsr"}
 #define  ImportbinaryOperators  {"import_binary", "import_grads"}
 #define  ImportcmsafOperators   {"import_cmsaf"}
@@ -345,7 +348,7 @@ void *Wct(void *argument);
 #define  SetOperators           {"setpartab", "setpartabv", "setcode", "setname", "setlevel", "setltype", "settabnum"}
 #define  SetboxOperators        {"setclonlatbox", "setcindexbox"}
 #define  SetgattOperators       {"setgatt", "setgatts"}
-#define  SetgridOperators       {"setgrid", "setgridtype", "setgridarea"}
+#define  SetgridOperators       {"setgrid", "setgridtype", "setgridarea", "setgridmask", "unsetgridmask"}
 #define  SethaloOperators       {"sethalo", "tpnhalo"}
 #define  SetmissOperators       {"setmissval", "setctomiss", "setmisstoc", "setrtomiss", "setvrange"}
 #define  SetrcanameOperators    {"setrcaname"}
@@ -411,6 +414,7 @@ void *Wct(void *argument);
 #define  WritegridOperators     {"writegrid"}
 #define  WriterandomOperators   {"writerandom"}
 #define  YhourstatOperators     {"yhourmin", "yhourmax", "yhoursum", "yhourmean", "yhouravg", "yhourvar", "yhourstd"}
+#define  YdayarithOperators     {"ydayadd", "ydaysub", "ydaymul", "ydaydiv"}
 #define  YdaypctlOperators      {"ydaypctl"}
 #define  YdaystatOperators      {"ydaymin", "ydaymax", "ydaysum", "ydaymean", "ydayavg", "ydayvar", "ydaystd"}
 #define  YdrunpctlOperators     {"ydrunpctl"}
@@ -506,7 +510,7 @@ static modules_t Modules[] =
   { Expr,           ExprHelp,          ExprOperators,          CDI_REAL,  1,  1 },
   { Filedes,        FiledesHelp,       FiledesOperators,       CDI_BOTH,  1,  0 },
   { Fillmiss,       NULL,              FillmissOperators,      CDI_REAL,  1,  1 },
-  { Filter,         NULL,              FilterOperators,        CDI_REAL,  1,  1 },
+  { Filter,         FilterHelp,        FilterOperators,        CDI_REAL,  1,  1 },
   { Fldrms,         NULL,              FldrmsOperators,        CDI_REAL,  2,  1 },
   { Fldstat,        FldstatHelp,       FldstatOperators,       CDI_REAL,  1,  1 },
   { Fldstat2,       FldcorHelp,        Fldstat2Operators,      CDI_REAL,  2,  1 },
@@ -518,6 +522,7 @@ static modules_t Modules[] =
   { Gridcell,       GridcellHelp,      GridcellOperators,      CDI_REAL,  1,  1 },
   { Harmonic,       NULL,              HarmonicOperators,      CDI_REAL,  1,  1 },
   { Histogram,      HistogramHelp,     HistogramOperators,     CDI_REAL,  1,  1 },
+  { IFS2ICON,       NULL,              IFS2ICONOperators,      CDI_REAL,  1,  1 },
   { Importamsr,     ImportamsrHelp,    ImportamsrOperators,    CDI_REAL,  1,  1 },
   { Importbinary,   ImportbinaryHelp,  ImportbinaryOperators,  CDI_REAL,  1,  1 },
   { Importcmsaf,    ImportcmsafHelp,   ImportcmsafOperators,   CDI_REAL,  1,  1 },
@@ -635,6 +640,7 @@ static modules_t Modules[] =
   { Writegrid,      NULL,              WritegridOperators,     CDI_REAL,  1,  1 },  /* no cdi output */
   { Writerandom,    NULL,              WriterandomOperators,   CDI_REAL,  1,  1 },
   { Yhourstat,      YhourstatHelp,     YhourstatOperators,     CDI_REAL,  1,  1 },
+  { Ydayarith,      NULL,              YdayarithOperators,     CDI_REAL,  2,  1 },
   { Ydaypctl,       YdaypctlHelp,      YdaypctlOperators,      CDI_REAL,  3,  1 },
   { Ydaystat,       YdaystatHelp,      YdaystatOperators,      CDI_REAL,  1,  1 },
   { Ydrunpctl,      YdrunpctlHelp,     YdrunpctlOperators,     CDI_REAL,  3,  1 },
@@ -784,7 +790,7 @@ char *operatorAlias(char *operatorName)
 static
 int operatorInqModID(char *operatorName)
 {
-  static char func[] = "operatorInqModID";
+  static const char *func = "operatorInqModID";
   int i, j, modID = -1;
 
   if ( operatorName )
